@@ -1148,14 +1148,23 @@ BEGIN
 END;$PROCEDURE$
 LANGUAGE plpgsql;
 
-CREATE OR REPLACE FUNCTION Getstorage_domains_List_By_storageDomainId (v_storage_domain_id UUID)
+CREATE OR REPLACE FUNCTION Getstorage_domains_List_By_storageDomainId (v_storage_domain_id UUID, v_user_id UUID, v_is_filtered BOOLEAN)
 RETURNS SETOF storage_domains STABLE AS $PROCEDURE$
 BEGIN
     RETURN QUERY
 
     SELECT *
     FROM storage_domains
-    WHERE storage_domains.id = v_storage_domain_id;
+    WHERE storage_domains.id = v_storage_domain_id
+    AND (
+            NOT v_is_filtered
+            OR EXISTS (
+                SELECT 1
+                FROM user_storage_pool_permissions_view
+                WHERE user_id = v_user_id
+                    AND entity_id = v_storage_domain_id
+                )
+            );
 END;$PROCEDURE$
 LANGUAGE plpgsql;
 
@@ -1329,3 +1338,100 @@ BEGIN
     FROM hosted_engine_storage_domains_ids_view;
 END;$PROCEDURE$
 LANGUAGE plpgsql;
+
+CREATE OR REPLACE FUNCTION GetStorageDomainByGlusterVolumeId (v_gluster_vol_id UUID)
+RETURNS SETOF storage_domains STABLE AS $PROCEDURE$
+BEGIN
+    RETURN QUERY
+
+    SELECT *
+    FROM storage_domains
+    WHERE storage IN (
+            SELECT id
+            FROM storage_server_connections
+            WHERE gluster_volume_id = v_gluster_vol_id
+            );
+END;$PROCEDURE$
+LANGUAGE plpgsql;
+
+-- ----------------------------------------------------------------
+-- [cinder_storage] Table
+--
+--This function is also called during installation. If you change it, please verify
+--that functions in inst_sp.sql can be executed successfully.
+CREATE OR REPLACE FUNCTION InsertCinderStorage (
+    v_storage_domain_id UUID,
+    v_driver_options JSONB,
+    v_driver_sensitive_options TEXT
+    )
+RETURNS VOID AS $PROCEDURE$
+BEGIN
+    INSERT INTO cinder_storage (
+        storage_domain_id,
+        driver_options,
+        driver_sensitive_options
+        )
+    VALUES (
+        v_storage_domain_id,
+        v_driver_options,
+        v_driver_sensitive_options
+        );
+END;$PROCEDURE$
+LANGUAGE plpgsql;
+
+CREATE OR REPLACE FUNCTION UpdateCinderStorage (
+    v_storage_domain_id UUID,
+    v_driver_options JSONB,
+    v_driver_sensitive_options TEXT
+    )
+RETURNS VOID
+    AS $PROCEDURE$
+BEGIN
+    UPDATE cinder_storage
+    SET driver_options = v_driver_options,
+        driver_sensitive_options = v_driver_sensitive_options
+    WHERE storage_domain_id = v_storage_domain_id;
+END;$PROCEDURE$
+LANGUAGE plpgsql;
+
+CREATE OR REPLACE FUNCTION DeleteCinderStorage (v_storage_domain_id UUID)
+RETURNS VOID AS $PROCEDURE$
+DECLARE v_val UUID;
+
+BEGIN
+    -- Get (and keep) a shared lock with "right to upgrade to exclusive"
+    -- in order to force locking parent before children
+    SELECT id
+    INTO v_val
+    FROM cinder_storage
+    WHERE storage_domain_id = v_storage_domain_id
+    FOR UPDATE;
+
+    DELETE
+    FROM cinder_storage
+    WHERE id = v_storage_domain_id;
+END;$PROCEDURE$
+LANGUAGE plpgsql;
+
+CREATE OR REPLACE FUNCTION GetCinderStorage (v_storage_domain_id UUID)
+RETURNS SETOF cinder_storage STABLE AS $PROCEDURE$
+BEGIN
+    RETURN QUERY
+
+    SELECT *
+    FROM cinder_storage
+    WHERE storage_domain_id = v_storage_domain_id;
+END;$PROCEDURE$
+LANGUAGE plpgsql;
+
+CREATE OR REPLACE FUNCTION GetCinderStorageByDrivers (
+    v_driver_options JSONB)
+RETURNS SETOF cinder_storage STABLE AS $PROCEDURE$
+BEGIN
+    RETURN QUERY
+
+    SELECT *
+    FROM cinder_storage
+    WHERE driver_options = v_driver_options;
+END;$PROCEDURE$
+LANGUAGE plpgsql;
