@@ -6,16 +6,12 @@ import java.util.List;
 import org.ovirt.engine.core.bll.context.EngineContext;
 import org.ovirt.engine.core.common.businessentities.VM;
 import org.ovirt.engine.core.common.businessentities.VmPool;
-import org.ovirt.engine.core.common.queries.VdcQueryParametersBase;
-import org.ovirt.engine.core.common.queries.VdcQueryReturnValue;
-import org.ovirt.engine.core.common.queries.VdcQueryType;
+import org.ovirt.engine.core.common.queries.QueryParametersBase;
+import org.ovirt.engine.core.common.queries.QueryReturnValue;
+import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
 
-public class GetAllVmsAndVmPoolsQuery<P extends VdcQueryParametersBase> extends QueriesCommandBase<P> {
-    public GetAllVmsAndVmPoolsQuery(P parameters) {
-        super(parameters);
-    }
-
+public class GetAllVmsAndVmPoolsQuery<P extends QueryParametersBase> extends QueriesCommandBase<P> {
     public GetAllVmsAndVmPoolsQuery(P parameters, EngineContext engineContext) {
         super(parameters, engineContext);
     }
@@ -27,8 +23,8 @@ public class GetAllVmsAndVmPoolsQuery<P extends VdcQueryParametersBase> extends
 
         // Add all VMs that the user has direct or indirect privileges on
         // that do not belong to a VM Pool
-        VdcQueryReturnValue queryResult =
-                runInternalQuery(VdcQueryType.GetAllVms, getParameters());
+        QueryReturnValue queryResult =
+                runInternalQuery(QueryType.GetAllVms, getParameters());
         if (queryResult != null && queryResult.getSucceeded()) {
             for (VM vm : queryResult.<List<VM>>getReturnValue()) {
                 if (Guid.isNullOrEmpty(vm.getVmPoolId())) {
@@ -42,7 +38,7 @@ public class GetAllVmsAndVmPoolsQuery<P extends VdcQueryParametersBase> extends
 
         // Query for all VMs the user has direct permissions on, if
         // a user has taken a VM from VM Pool it should be returned here
-        queryResult = runInternalQuery(VdcQueryType.GetAllVmsForUser, getParameters());
+        queryResult = runInternalQuery(QueryType.GetAllVmsForUser, getParameters());
         if (queryResult != null && queryResult.getSucceeded()) {
             for (VM vm : queryResult.<List<VM>>getReturnValue()) {
                 if (!retValList.contains(vm)) {
@@ -55,8 +51,8 @@ public class GetAllVmsAndVmPoolsQuery<P extends VdcQueryParametersBase> extends
 
         if (isSucceeded) {
             queryResult =
-                    runInternalQuery(VdcQueryType.GetAllVmPoolsAttachedToUser,
-                            new VdcQueryParametersBase());
+                    runInternalQuery(QueryType.GetAllVmPoolsAttachedToUser,
+                            new QueryParametersBase());
             if (queryResult != null && queryResult.getSucceeded()) {
                 retValList.addAll(queryResult.<List<VmPool>>getReturnValue());
             } else {
