@@ -62,7 +62,7 @@ import org.ovirt.engine.core.vdsbroker.vdsbroker.CancelMigrationVDSParameters;
 @InternalCommandAttribute
 @NonTransactiveCommandAttribute
 public class MaintenanceNumberOfVdssCommand<T extends MaintenanceNumberOfVdssParameters> extends CommandBase<T> {
-    private final HashMap<Guid, VDS> vdssToMaintenance = new HashMap<>();
+    private final Map<Guid, VDS> vdssToMaintenance = new HashMap<>();
     private final List<PermissionSubject> inspectedEntitiesMap;
     private Map<String, Pair<String, String>> sharedLockMap;
 
@@ -270,8 +270,7 @@ public class MaintenanceNumberOfVdssCommand<T extends MaintenanceNumberOfVdssPar
                             && (vds.getStatus() != VDSStatus.NonOperational
                             && (vds.getStatus() != VDSStatus.InstallFailed))) {
                         result = failValidation(EngineMessage.VDS_CANNOT_MAINTENANCE_VDS_IS_NOT_OPERATIONAL);
-                    }
-                    else {
+                    } else {
                         List<VM> vms = vmDao.getAllRunningForVds(vdsId);
                         if (!vms.isEmpty()) {
                             vdsWithRunningVMs.add(vdsId);
@@ -293,9 +292,13 @@ public class MaintenanceNumberOfVdssCommand<T extends MaintenanceNumberOfVdssPar
                                     return false;
                                 }
                             }
+
+                            boolean vmNonMigratable = vm.getMigrationSupport() == MigrationSupport.PINNED_TO_HOST ||
+                                    (vm.getMigrationSupport() == MigrationSupport.IMPLICITLY_NON_MIGRATABLE && getParameters().getIsInternal());
+
                             // The Hosted Engine VM is migrated by the HA agent;
                             // other non-migratable VMs are reported
-                            if (vm.getMigrationSupport() != MigrationSupport.MIGRATABLE && !vm.isHostedEngine()) {
+                            if (vmNonMigratable && !vm.isHostedEngine()) {
                                 nonMigratableVmDescriptionsToFrontEnd.add(vm.getName());
                             }
                         }
