@@ -35,8 +35,6 @@ import org.ovirt.engine.core.common.locks.LockingGroup;
 import org.ovirt.engine.core.common.utils.Pair;
 import org.ovirt.engine.core.common.validation.group.CreateEntity;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.core.dal.dbbroker.DbFacade;
-import org.ovirt.engine.core.dao.VmDao;
 import org.ovirt.engine.core.dao.network.NetworkDao;
 import org.ovirt.engine.core.dao.network.NetworkFilterDao;
 import org.ovirt.engine.core.dao.network.VnicProfileDao;
@@ -56,8 +54,6 @@ public class AddNetworkCommand<T extends AddNetworkStoragePoolParameters> extend
     @Inject
     private ProviderDao providerDao;
     @Inject
-    private VmDao vmDao;
-    @Inject
     private NetworkLocking networkLocking;
 
     public AddNetworkCommand(T parameters, CommandContext cmdContext) {
@@ -109,7 +105,7 @@ public class AddNetworkCommand<T extends AddNetworkStoragePoolParameters> extend
     }
 
     protected AddNetworkValidator getNetworkValidator() {
-        return new AddNetworkValidator(vmDao, getNetwork());
+        return new AddNetworkValidator(getNetwork());
     }
 
     private boolean externalNetworkValid(AddNetworkValidator validator) {
@@ -192,8 +188,8 @@ public class AddNetworkCommand<T extends AddNetworkStoragePoolParameters> extend
 
     protected static class AddNetworkValidator extends NetworkValidator {
 
-        public AddNetworkValidator(VmDao vmDao, Network network) {
-            super(vmDao, network);
+        public AddNetworkValidator(Network network) {
+            super(network);
         }
 
         public ValidationResult externalNetworkVlanValid() {
@@ -202,11 +198,6 @@ public class AddNetworkCommand<T extends AddNetworkStoragePoolParameters> extend
                             .hasCustomPhysicalNetworkName());
         }
 
-        @Override
-        protected DbFacade getDbFacade() {
-            return super.getDbFacade();
-        }
-
         /**
          * @return An error iff the network represents an external network that already exists in the data center that
          *         the network should be on.
