@@ -5,6 +5,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.stream.Collectors;
 
+import javax.enterprise.inject.Instance;
+import javax.enterprise.inject.Typed;
 import javax.inject.Inject;
 
 import org.ovirt.engine.core.bll.CommandBase;
@@ -16,13 +18,14 @@ import org.ovirt.engine.core.bll.context.CommandContext;
 import org.ovirt.engine.core.bll.tasks.interfaces.CommandCallback;
 import org.ovirt.engine.core.bll.utils.CommandsWeightsUtils;
 import org.ovirt.engine.core.bll.utils.PermissionSubject;
+import org.ovirt.engine.core.common.action.ActionParametersBase.EndProcedure;
+import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.action.CloneImageGroupVolumesStructureCommandParameters;
 import org.ovirt.engine.core.common.action.CreateVolumeContainerCommandParameters;
-import org.ovirt.engine.core.common.action.VdcActionParametersBase.EndProcedure;
-import org.ovirt.engine.core.common.action.VdcActionType;
-import org.ovirt.engine.core.common.businessentities.StorageDomainStatic;
 import org.ovirt.engine.core.common.businessentities.storage.DiskImage;
 import org.ovirt.engine.core.compat.Guid;
+import org.ovirt.engine.core.dao.DiskImageDao;
+import org.ovirt.engine.core.dao.ImageDao;
 
 @InternalCommandAttribute
 @NonTransactiveCommandAttribute
@@ -30,6 +33,16 @@ public class CloneImageGroupVolumesStructureCommand<T extends CloneImageGroupVol
 
     @Inject
     private CommandsWeightsUtils commandsWeightsUtils;
+    @Inject
+    private DiskImageDao diskImageDao;
+    @Inject
+    private ImageDao imageDao;
+    @Inject
+    @Typed(SerialChildCommandsExecutionCallback.class)
+    private Instance<SerialChildCommandsExecutionCallback> callbackProvider;
+
+    @Inject
+    private ImagesHandler imagesHandler;
 
     public CloneImageGroupVolumesStructureCommand(T parameters, CommandContext cmdContext) {
         super(parameters, cmdContext);
@@ -66,14 +79,9 @@ public class CloneImageGroupVolumesStructureCommand<T extends CloneImageGroupVol
 
     @Override
     public CommandCallback getCallback() {
-        return new SerialChildCommandsExecutionCallback();
+        return callbackProvider.get();
     }
 
-    private StorageDomainStatic getStorageDomainStatic(Guid domainId) {
-        return storageDomainStaticDao.get(domainId);
-    }
-
-
     @Override
     public boolean performNextOperation(int completedChildren) {
         if (completedChildren == getParameters().getImageIds().size()) {
@@ -112,7 +120,7 @@ public class CloneImageGroupVolumesStructureCommand<T extends CloneImageGroupVol
                 image.getVolumeFormat(),
                 getParameters().getDescription(),
                 image.getSize(),
-                ImagesHandler.determineImageInitialSize(image.getImage(),
+                imagesHandler.determineImageInitialSize(image.getImage(),
                         image.getVolumeFormat(),
                         getParameters().getStoragePoolId(),
                         getParameters().getSrcDomain(),
@@ -123,7 +131,7 @@ public class CloneImageGroupVolumesStructureCommand<T extends CloneImageGroupVol
         parameters.setParentCommand(getActionType());
         parameters.setParentParameters(getParameters());
         parameters.setJobWeight(getParameters().getOperationsJobWeight().get(image.getImageId().toString()));
-        runInternalActionWithTasksContext(VdcActionType.CreateVolumeContainer, parameters);
+        runInternalActionWithTasksContext(ActionType.CreateVolumeContainer, parameters);
     }
 
     @Override
