@@ -19,7 +19,6 @@ import org.ovirt.engine.core.bll.hostdev.HostDeviceManager;
 import org.ovirt.engine.core.bll.storage.disk.image.DisksFilter;
 import org.ovirt.engine.core.bll.validator.storage.DiskImagesValidator;
 import org.ovirt.engine.core.common.ActionUtils;
-import org.ovirt.engine.core.common.FeatureSupported;
 import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.businessentities.MigrationSupport;
 import org.ovirt.engine.core.common.businessentities.Snapshot.SnapshotType;
@@ -42,9 +41,11 @@ import org.ovirt.engine.core.common.osinfo.OsRepository;
 import org.ovirt.engine.core.common.utils.customprop.VmPropertiesUtils;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.compat.Version;
-import org.ovirt.engine.core.dal.dbbroker.DbFacade;
 import org.ovirt.engine.core.dao.DiskDao;
 import org.ovirt.engine.core.dao.DiskVmElementDao;
+import org.ovirt.engine.core.dao.SnapshotDao;
+import org.ovirt.engine.core.dao.network.VmNetworkInterfaceDao;
+import org.ovirt.engine.core.dao.network.VnicProfileDao;
 import org.ovirt.engine.core.di.Injector;
 import org.ovirt.engine.core.utils.ReplacementUtils;
 
@@ -114,7 +115,7 @@ public class VmValidator {
         return ValidationResult.VALID;
     }
 
-    public ValidationResult vmNotIlegal() {
+    public ValidationResult vmNotIllegal() {
         if (vm.getStatus() == VMStatus.ImageIllegal) {
             return new ValidationResult(EngineMessage.ACTION_TYPE_FAILED_VM_IMAGE_IS_ILLEGAL);
         }
@@ -135,7 +136,7 @@ public class VmValidator {
     }
 
     public ValidationResult vmNotRunningStateless() {
-        if (DbFacade.getInstance().getSnapshotDao().exists(vm.getId(), SnapshotType.STATELESS)) {
+        if (Injector.get(SnapshotDao.class).exists(vm.getId(), SnapshotType.STATELESS)) {
             EngineMessage message = vm.isRunning() ? EngineMessage.ACTION_TYPE_FAILED_VM_RUNNING_STATELESS :
                     EngineMessage.ACTION_TYPE_FAILED_VM_HAS_STATELESS_SNAPSHOT_LEFTOVER;
             return new ValidationResult(message);
@@ -148,7 +149,7 @@ public class VmValidator {
      * @return ValidationResult indicating whether snapshots of disks are attached to other vms.
      */
     public ValidationResult vmNotHavingDeviceSnapshotsAttachedToOtherVms(boolean onlyPlugged) {
-        List<Disk> vmDisks = getDbFacade().getDiskDao().getAllForVm(vm.getId());
+        List<Disk> vmDisks = getDiskDao().getAllForVm(vm.getId());
         ValidationResult result =
                 new DiskImagesValidator(DisksFilter.filterImageDisks(vmDisks, ONLY_NOT_SHAREABLE, ONLY_ACTIVE))
                         .diskImagesSnapshotsNotAttachedToOtherVms(onlyPlugged);
@@ -187,19 +188,14 @@ public class VmValidator {
     }
 
     public DiskDao getDiskDao() {
-        return getDbFacade().getDiskDao();
-    }
-
-    public DbFacade getDbFacade() {
-        return DbFacade.getInstance();
+        return Injector.get(DiskDao.class);
     }
 
     /**
      * @return ValidationResult indicating whether a vm contains non-migratable, plugged, passthrough vnics
      */
     public ValidationResult allPassthroughVnicsMigratable() {
-        List<VmNetworkInterface> vnics =
-                getDbFacade().getVmNetworkInterfaceDao().getAllForVm(vm.getId());
+        List<VmNetworkInterface> vnics = Injector.get(VmNetworkInterfaceDao.class).getAllForVm(vm.getId());
 
         List<String> nonMigratablePassthroughVnicNames = vnics.stream()
                 .filter(isVnicMigratable(vm).negate())
@@ -218,13 +214,11 @@ public class VmValidator {
     }
 
     private Predicate<? super VmNetworkInterface> isVnicMigratable(VM vm) {
-        return vnic -> !vnic.isPassthrough() || !vnic.isPlugged()
-                || (FeatureSupported.sriovHotPlugSupported(vm.getClusterCompatibilityVersion())
-                        && getVnicProfile(vnic).isMigratable());
+        return vnic -> !vnic.isPassthrough() || !vnic.isPlugged() || getVnicProfile(vnic).isMigratable();
     }
 
     private VnicProfile getVnicProfile(VmNic vnic) {
-        VnicProfile profile = getDbFacade().getVnicProfileDao().get(vnic.getVnicProfileId());
+        VnicProfile profile = Injector.get(VnicProfileDao.class).get(vnic.getVnicProfileId());
         return profile;
     }
 
@@ -233,7 +227,7 @@ public class VmValidator {
      * @return If scsi lun with scsi reservation is plugged to VM
      */
     public ValidationResult isVmPluggedDiskNotUsingScsiReservation() {
-        List<DiskVmElement> dves = getDbFacade().getDiskVmElementDao().getAllPluggedToVm(vm.getId());
+        List<DiskVmElement> dves = getDiskVmElementDao().getAllPluggedToVm(vm.getId());
         if (dves.stream().anyMatch(dve -> dve.isUsingScsiReservation())) {
             return new ValidationResult(EngineMessage.ACTION_TYPE_FAILED_VM_USES_SCSI_RESERVATION,
                     String.format("$VmName %s", vm.getName()));
@@ -336,15 +330,16 @@ public class VmValidator {
         ArrayList<EngineMessage> messages = new ArrayList<>();
         if (pciInUse > maxPciSlots) {
             messages.add(EngineMessage.ACTION_TYPE_FAILED_EXCEEDED_MAX_PCI_SLOTS);
-        }
-        else if (VmCommand.MAX_IDE_SLOTS < diskVmElements.stream().filter(a -> a.getDiskInterface() == DiskInterface.IDE).count()) {
+        } else if (VmCommand.MAX_IDE_SLOTS <
+                diskVmElements.stream().filter(a -> a.getDiskInterface() == DiskInterface.IDE).count()) {
             messages.add(EngineMessage.ACTION_TYPE_FAILED_EXCEEDED_MAX_IDE_SLOTS);
-        }
-        else if (VmCommand.MAX_VIRTIO_SCSI_DISKS <
+        } else if (VmCommand.MAX_SATA_SLOTS <
+                diskVmElements.stream().filter(a -> a.getDiskInterface() == DiskInterface.SATA).count()) {
+            messages.add(EngineMessage.ACTION_TYPE_FAILED_EXCEEDED_MAX_SATA_SLOTS);
+        } else if (VmCommand.MAX_VIRTIO_SCSI_DISKS <
                 diskVmElements.stream().filter(a -> a.getDiskInterface() == DiskInterface.VirtIO_SCSI).count()) {
             messages.add(EngineMessage.ACTION_TYPE_FAILED_EXCEEDED_MAX_VIRTIO_SCSI_DISKS);
-        }
-        else if (VmCommand.MAX_SPAPR_SCSI_DISKS <
+        } else if (VmCommand.MAX_SPAPR_SCSI_DISKS <
                 diskVmElements.stream().filter(a -> a.getDiskInterface() == DiskInterface.SPAPR_VSCSI).count()) {
             messages.add(EngineMessage.ACTION_TYPE_FAILED_EXCEEDED_MAX_SPAPR_VSCSI_DISKS);
         }
@@ -388,7 +383,7 @@ public class VmValidator {
     }
 
     public DiskVmElementDao getDiskVmElementDao() {
-        return DbFacade.getInstance().getDiskVmElementDao();
+        return Injector.get(DiskVmElementDao.class);
     }
 
 }
