@@ -8,14 +8,12 @@ import java.util.Set;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
-import org.ovirt.engine.core.bll.Backend;
 import org.ovirt.engine.core.bll.ValidationResult;
 import org.ovirt.engine.core.bll.VmHandler;
 import org.ovirt.engine.core.bll.interfaces.BackendInternal;
 import org.ovirt.engine.core.bll.storage.disk.image.DisksFilter;
 import org.ovirt.engine.core.bll.storage.disk.image.ImagesHandler;
 import org.ovirt.engine.core.bll.storage.utils.BlockStorageDiscardFunctionalityHelper;
-import org.ovirt.engine.core.common.FeatureSupported;
 import org.ovirt.engine.core.common.action.ActionType;
 import org.ovirt.engine.core.common.businessentities.StorageDomain;
 import org.ovirt.engine.core.common.businessentities.StorageDomainDynamic;
@@ -40,8 +38,6 @@ import org.ovirt.engine.core.common.queries.IdQueryParameters;
 import org.ovirt.engine.core.common.queries.QueryReturnValue;
 import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.compat.Guid;
-import org.ovirt.engine.core.compat.Version;
-import org.ovirt.engine.core.dal.dbbroker.DbFacade;
 import org.ovirt.engine.core.dao.VmDao;
 import org.ovirt.engine.core.dao.VmDynamicDao;
 import org.ovirt.engine.core.di.Injector;
@@ -459,15 +455,6 @@ public class StorageDomainValidator {
                 EngineMessage.ACTION_TYPE_FAILED_DISCARD_AFTER_DELETE_SUPPORTED_ONLY_BY_BLOCK_DOMAINS);
     }
 
-    public ValidationResult isDiscardAfterDeleteSupportedByDcVersion(Version version) {
-        if (storageDomain.getDiscardAfterDelete() && !FeatureSupported.discardAfterDeleteSupported(version)) {
-            return new ValidationResult(
-                    EngineMessage.ACTION_TYPE_FAILED_DISCARD_AFTER_DELETE_NOT_SUPPORTED_BY_DC_VERSION,
-                    String.format("$dataCenterVersion %s", version.toString()));
-        }
-        return ValidationResult.VALID;
-    }
-
     public ValidationResult isRunningVmsOrVmLeasesForBackupDomain(VmHandler vmHandler) {
         Set<String> invalidVmsForBackupStorageDomain = new HashSet<>();
         QueryReturnValue ret = getEntitiesWithLeaseIdForStorageDomain(storageDomain.getId());
@@ -514,14 +501,14 @@ public class StorageDomainValidator {
     }
 
     private BackendInternal getBackend() {
-        return Backend.getInstance();
+        return Injector.get(BackendInternal.class);
     }
 
     protected VmDao getVmDao() {
-        return DbFacade.getInstance().getVmDao();
+        return Injector.get(VmDao.class);
     }
 
     protected VmDynamicDao getVmDynamicDao() {
-        return DbFacade.getInstance().getVmDynamicDao();
+        return Injector.get(VmDynamicDao.class);
     }
 }
