@@ -1,23 +1,24 @@
 package org.ovirt.engine.core.bll;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyInt;
-import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
 
 import java.util.Collections;
-import java.util.HashMap;
+import java.util.Map;
 import java.util.Set;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 import org.ovirt.engine.core.common.action.WatchdogParameters;
 import org.ovirt.engine.core.common.businessentities.VM;
 import org.ovirt.engine.core.common.businessentities.VmDevice;
@@ -29,7 +30,9 @@ import org.ovirt.engine.core.common.osinfo.OsRepository;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.dao.VmDao;
 import org.ovirt.engine.core.dao.VmDeviceDao;
+import org.ovirt.engine.core.utils.InjectedMock;
 
+@MockitoSettings(strictness = Strictness.LENIENT)
 public class UpdateWatchdogCommandTest extends BaseCommandTest {
 
     private VmWatchdogType vmWatchdogType = VmWatchdogType.i6300esb;
@@ -42,13 +45,15 @@ public class UpdateWatchdogCommandTest extends BaseCommandTest {
     @Mock
     private VmDeviceDao vmDeviceDaoMock;
 
+    @Mock
+    @InjectedMock
+    public OsRepository osRepository;
+
     @InjectMocks
     private UpdateWatchdogCommand command = new UpdateWatchdogCommand(new WatchdogParameters(), null);
 
-    @Before
+    @BeforeEach
     public void setUpOsRepository() {
-        OsRepository osRepository = mock(OsRepository.class);
-        injectorRule.bind(OsRepository.class, osRepository);
         when(osRepository.getVmWatchdogTypes(anyInt(), any())).thenReturn(WATCHDOG_MODELS);
     }
 
@@ -56,7 +61,7 @@ public class UpdateWatchdogCommandTest extends BaseCommandTest {
     public void getSpecParams() {
         command.getParameters().setAction(VmWatchdogAction.RESET);
         command.getParameters().setModel(vmWatchdogType);
-        HashMap<String, Object> specParams = command.getSpecParams();
+        Map<String, Object> specParams = command.getSpecParams();
         assertNotNull(specParams);
         assertEquals("i6300esb", specParams.get("model"));
         assertEquals("reset", specParams.get("action"));
