@@ -23,6 +23,7 @@ public enum QueryType implements Serializable {
     GetVmConfigurationBySnapshot(QueryAuthType.User),
     GetVmFromConfiguration(QueryAuthType.User),
     GetVmTemplateFromConfiguration(QueryAuthType.User),
+    GetVmTemplateFromOva,
     GetVmOvfByVmId(QueryAuthType.User),
     GetSnapshotBySnapshotId(QueryAuthType.User),
     GetVmsByDiskGuid,
@@ -44,6 +45,7 @@ public enum QueryType implements Serializable {
     GetVmIconDefault(QueryAuthType.User),
     GetVmDevicesForVm(QueryAuthType.User),
     GetVmsPinnedToHost(QueryAuthType.User),
+    GetAllVmsRunningForMultipleVds(QueryAuthType.User),
     GetVmByVmIdForUpdate(QueryAuthType.User),
 
     // Vds queries
@@ -96,6 +98,7 @@ public enum QueryType implements Serializable {
     GetAllUnmanagedNetworksByHostId,
     GetUnmanagedNetworkByHostIdAndName,
     GetNetworksByDataCenterId(QueryAuthType.User),
+    GetRequiredNetworksByDataCenterId,
     GetAllNetworksByQosId,
     GetManagementInterfaceAddressByVmId(QueryAuthType.User),
     GetInterfacesByLabelForNetwork,
@@ -335,6 +338,8 @@ public enum QueryType implements Serializable {
     GetAllMacPools,
     GetStoragePoolByDatacenterName(QueryAuthType.User),
     GetStorageDomainsByConnection,
+    GetManagedBlockStorageDomainsByDrivers,
+    GetManagedBlockStorageDomainById,
     GetConnectionsByDataCenterAndStorageType,
     GetStorageDomainsByStoragePoolId(QueryAuthType.User),
     GetStorageDomainsByImageId,
@@ -350,7 +355,7 @@ public enum QueryType implements Serializable {
     GetStorageDomainByIdAndStoragePoolId,
     GetStoragePoolsByStorageDomainId,
     GetStoragePoolsByClusterService(QueryAuthType.User),
-    GetStorageDomainListById,
+    GetStorageDomainListById(QueryAuthType.User),
     GetLunsByVgId,
     GetPermittedStorageDomainsByStoragePoolId(QueryAuthType.User),
     GetIscsiBondsByStoragePoolId,
@@ -388,7 +393,6 @@ public enum QueryType implements Serializable {
     GetTemplatesRelatedToQuotaId,
     GetPermissionsToConsumeQuotaByQuotaId,
     GetQuotasByAdElementId,
-    GetQuotasConsumptionForCurrentUser(QueryAuthType.User),
     GetAllRelevantQuotasForStorage(QueryAuthType.User),
     GetAllRelevantQuotasForCluster(QueryAuthType.User),
 
