@@ -1,18 +1,21 @@
 package org.ovirt.engine.core.common.utils;
 
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.when;
 
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
 import org.mockito.Mock;
 import org.mockito.Spy;
-import org.mockito.junit.MockitoJUnitRunner;
+import org.mockito.junit.jupiter.MockitoExtension;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 import org.ovirt.engine.core.common.validation.MaskValidator;
 
-@RunWith(MockitoJUnitRunner.class)
+@ExtendWith(MockitoExtension.class)
+@MockitoSettings(strictness = Strictness.LENIENT)
 public class SubnetUtilsTest {
 
     private static final String VALID_PREFIX = "VALID_PREFIX";
@@ -29,7 +32,7 @@ public class SubnetUtilsTest {
     @Mock
     private IPAddressConverter mockIpAddressConverter;
 
-    @Before
+    @BeforeEach
     public void setup() {
         when(underTest.getMaskValidator()).thenReturn(mockedMaskValidator);
         when(underTest.getIpAddressConverter()).thenReturn(mockIpAddressConverter);
