@@ -1,21 +1,22 @@
 package org.ovirt.engine.core.dao;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.List;
 import java.util.stream.Collectors;
 
 import javax.inject.Inject;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.ovirt.engine.core.common.businessentities.ArchitectureType;
 import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.Label;
 import org.ovirt.engine.core.common.businessentities.LabelBuilder;
+import org.ovirt.engine.core.common.businessentities.LogMaxMemoryUsedThresholdType;
 import org.ovirt.engine.core.common.businessentities.VdsStatic;
 import org.ovirt.engine.core.common.businessentities.VmStatic;
 import org.ovirt.engine.core.common.network.FirewallType;
@@ -24,10 +25,7 @@ import org.ovirt.engine.core.compat.Version;
 
 import com.google.common.collect.Lists;
 
-public class LabelDaoTest extends BaseDaoTestCase {
-    @Inject
-    private LabelDao labelDao;
-
+public class LabelDaoTest extends BaseDaoTestCase<LabelDao> {
     @Inject
     private VmStaticDao vmDao;
 
@@ -39,16 +37,18 @@ public class LabelDaoTest extends BaseDaoTestCase {
 
     private VdsStatic host;
 
+    @BeforeEach
     @Override
-    @Before
     public void setUp() {
         Cluster cluster = new Cluster();
         cluster.setName("test-cluster");
         cluster.setId(Guid.newGuid());
-        cluster.setCompatibilityVersion(Version.v3_6);
+        cluster.setCompatibilityVersion(Version.v4_3);
         cluster.setArchitecture(ArchitectureType.x86);
         cluster.setMacPoolId(FixturesTool.DEFAULT_MAC_POOL_ID);
         cluster.setFirewallType(FirewallType.IPTABLES);
+        cluster.setLogMaxMemoryUsedThreshold(95);
+        cluster.setLogMaxMemoryUsedThresholdType(LogMaxMemoryUsedThresholdType.PERCENTAGE);
 
         clusterDao.save(cluster);
 
@@ -70,8 +70,8 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .id(guid)
                 .build();
 
-        labelDao.save(label);
-        Label read = labelDao.get(guid);
+        dao.save(label);
+        Label read = dao.get(guid);
 
         assertNotNull(read);
         assertEquals(guid, read.getId());
@@ -87,8 +87,8 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .id(guid)
                 .build();
 
-        labelDao.save(label);
-        List<Label> readList = labelDao.getAll();
+        dao.save(label);
+        List<Label> readList = dao.getAll();
 
         assertNotNull(readList);
 
@@ -111,8 +111,8 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .vm(vm.getId())
                 .build();
 
-        labelDao.save(label);
-        Label read = labelDao.get(guid);
+        dao.save(label);
+        Label read = dao.get(guid);
 
         assertNotNull(read);
         assertEquals(guid, read.getId());
@@ -133,8 +133,8 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(host)
                 .build();
 
-        labelDao.save(label);
-        Label read = labelDao.get(guid);
+        dao.save(label);
+        Label read = dao.get(guid);
 
         assertNotNull(read);
         assertEquals(guid, read.getId());
@@ -153,7 +153,7 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(host)
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
         VmStatic vm = createAndSaveVm();
 
@@ -163,7 +163,7 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(vm)
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
         VmStatic vm2 = createAndSaveVm();
 
@@ -173,9 +173,9 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(vm2)
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
-        List<Label> read = labelDao.getAllByEntityIds(Lists.newArrayList(host.getId(), vm.getId(), Guid.newGuid()));
+        List<Label> read = dao.getAllByEntityIds(Lists.newArrayList(host.getId(), vm.getId(), Guid.newGuid()));
 
         assertNotNull(read);
         assertEquals(2, read.size());
@@ -189,7 +189,7 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(host)
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
         VmStatic vm = createAndSaveVm();
         VmStatic vm2 = createAndSaveVm();
@@ -200,7 +200,7 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(vm)
                 .build();
 
-        labelDao.save(label2);
+        dao.save(label2);
 
         label = new LabelBuilder()
                 .name("test label not in result")
@@ -208,9 +208,9 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entity(vm2)
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
-        List<Label> read = labelDao.getAllByIds(Lists.newArrayList(label.getId(), label2.getId()));
+        List<Label> read = dao.getAllByIds(Lists.newArrayList(label.getId(), label2.getId()));
 
         assertNotNull(read);
         assertEquals(2, read.size());
@@ -226,9 +226,9 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .entities(host, vm)
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
-        List<Label> read = labelDao.getAllByEntityIds(Lists.newArrayList(host.getId(), vm.getId()));
+        List<Label> read = dao.getAllByEntityIds(Lists.newArrayList(host.getId(), vm.getId()));
 
         assertNotNull(read);
         assertEquals(1, read.size());
@@ -244,9 +244,9 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .host(host.getId())
                 .build();
 
-        labelDao.save(label);
-        labelDao.remove(label.getId());
-        Label read = labelDao.get(guid);
+        dao.save(label);
+        dao.remove(label.getId());
+        Label read = dao.get(guid);
 
         assertNull(read);
     }
@@ -262,9 +262,9 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .map(Label::getId)
                 .collect(Collectors.toList());
 
-        labelDao.addVmToLabels(vm.getId(), guidsForLabelsToAssign);
+        dao.addVmToLabels(vm.getId(), guidsForLabelsToAssign);
 
-        List<Label> assignedLabels = labelDao.getAllByEntityIds(Lists.newArrayList(vm.getId()));
+        List<Label> assignedLabels = dao.getAllByEntityIds(Lists.newArrayList(vm.getId()));
 
         assertNotNull(assignedLabels);
         assertTrue(labelsToAssign.containsAll(assignedLabels) && assignedLabels.containsAll(labelsToAssign));
@@ -280,9 +280,9 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .map(Label::getId)
                 .collect(Collectors.toList());
 
-        labelDao.addHostToLabels(host.getId(), guidsForLabelsToAssign);
+        dao.addHostToLabels(host.getId(), guidsForLabelsToAssign);
 
-        List<Label> assignedLabels = labelDao.getAllByEntityIds(Lists.newArrayList(host.getId()));
+        List<Label> assignedLabels = dao.getAllByEntityIds(Lists.newArrayList(host.getId()));
 
         assertNotNull(assignedLabels);
         assertTrue(labelsToAssign.containsAll(assignedLabels) && assignedLabels.containsAll(labelsToAssign));
@@ -293,13 +293,13 @@ public class LabelDaoTest extends BaseDaoTestCase {
         VmStatic vm = createAndSaveVm();
 
         Label label = createAndSaveLabel("test_label");
-        labelDao.addVmToLabels(vm.getId(), Lists.newArrayList(label.getId()));
+        dao.addVmToLabels(vm.getId(), Lists.newArrayList(label.getId()));
 
         Label label2 = createAndSaveLabel("test_label_2");
 
-        labelDao.updateLabelsForVm(vm.getId(), Lists.newArrayList(label2.getId()));
+        dao.updateLabelsForVm(vm.getId(), Lists.newArrayList(label2.getId()));
 
-        List<Label> assignedLabels = labelDao.getAllByEntityIds(Lists.newArrayList(vm.getId()));
+        List<Label> assignedLabels = dao.getAllByEntityIds(Lists.newArrayList(vm.getId()));
 
         assertNotNull(assignedLabels);
         assertEquals(Lists.newArrayList(label2), assignedLabels);
@@ -308,13 +308,13 @@ public class LabelDaoTest extends BaseDaoTestCase {
     @Test
     public void testUpdateLabelsForHost() {
         Label label = createAndSaveLabel("test_label");
-        labelDao.addHostToLabels(host.getId(), Lists.newArrayList(label.getId()));
+        dao.addHostToLabels(host.getId(), Lists.newArrayList(label.getId()));
 
         Label label2 = createAndSaveLabel("test_label_2");
 
-        labelDao.updateLabelsForHost(host.getId(), Lists.newArrayList(label2.getId()));
+        dao.updateLabelsForHost(host.getId(), Lists.newArrayList(label2.getId()));
 
-        List<Label> assignedLabels = labelDao.getAllByEntityIds(Lists.newArrayList(host.getId()));
+        List<Label> assignedLabels = dao.getAllByEntityIds(Lists.newArrayList(host.getId()));
 
         assertNotNull(assignedLabels);
         assertEquals(Lists.newArrayList(label2), assignedLabels);
@@ -331,14 +331,14 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .map(Label::getId)
                 .collect(Collectors.toList());
 
-        labelDao.addVmToLabels(vm.getId(), guidsForLabelsToAssign);
+        dao.addVmToLabels(vm.getId(), guidsForLabelsToAssign);
 
         guidsForLabelsToAssign.remove(label2.getId());
-        labelDao.updateLabelsForVm(vm.getId(), guidsForLabelsToAssign);
+        dao.updateLabelsForVm(vm.getId(), guidsForLabelsToAssign);
 
-        List<Label> labelsForVm = labelDao.getAllByEntityIds(Lists.newArrayList(vm.getId()));
+        List<Label> labelsForVm = dao.getAllByEntityIds(Lists.newArrayList(vm.getId()));
 
-        assertTrue(labelsForVm.size() == 1);
+        assertEquals(1, labelsForVm.size());
         assertEquals(label, labelsForVm.get(0));
     }
 
@@ -348,7 +348,7 @@ public class LabelDaoTest extends BaseDaoTestCase {
                 .id(Guid.newGuid())
                 .build();
 
-        labelDao.save(label);
+        dao.save(label);
 
         return label;
     }
