@@ -151,6 +151,10 @@ public class BackendHostResource extends AbstractBackendActionableResource<Host,
                 return doAction(ActionType.UpgradeOvirtNode, params, action);
             }
         }
+        // Installation is only done in maintenance mode, and should by default leave the host in maintenance mode.
+        // this is why the default value for 'activate' here is false (vs in adding or approving a host, where it is 'true')
+        boolean activate = ParametersHelper.getBooleanParameter(httpHeaders, uriInfo, BackendHostsResource.ACTIVATE, true, false);
+        params.setActivateHost(activate);
         return doAction(ActionType.UpdateVds,
                         params,
                         action);
@@ -199,8 +203,7 @@ public class BackendHostResource extends AbstractBackendActionableResource<Host,
         if (action.isSetRootPassword()) {
             params.setAuthMethod(VdsOperationActionParameters.AuthenticationMethod.Password);
             params.setRootPassword(action.getRootPassword());
-        }
-        else if (action.isSetSsh() && action.getSsh().isSetAuthenticationMethod()) {
+        } else if (action.isSetSsh() && action.getSsh().isSetAuthenticationMethod()) {
             if (action.getSsh().getAuthenticationMethod() == SshAuthenticationMethod.PASSWORD) {
                 params.setAuthMethod(VdsOperationActionParameters.AuthenticationMethod.Password);
                 if (action.getSsh().isSetUser() && action.getSsh().getUser().isSetPassword()) {
@@ -208,6 +211,9 @@ public class BackendHostResource extends AbstractBackendActionableResource<Host,
                 }
             }
         }
+        // by default activate the host after approval
+        boolean activate = ParametersHelper.getBooleanParameter(httpHeaders, uriInfo, BackendHostsResource.ACTIVATE, true, true);
+        params.setActivateHost(activate);
 
         return doAction(ActionType.ApproveVds,
                         params,
@@ -311,6 +317,8 @@ public class BackendHostResource extends AbstractBackendActionableResource<Host,
             parameters.setConectivityTimeout(action.getConnectivityTimeout());
         }
 
+        parameters.setCommitOnSuccess(action.isSetCommitOnSuccess() && action.isCommitOnSuccess());
+
         return parameters;
     }
 
@@ -350,17 +358,26 @@ public class BackendHostResource extends AbstractBackendActionableResource<Host,
             org.ovirt.engine.api.model.NetworkAttachment model) {
         Mapper<org.ovirt.engine.api.model.NetworkAttachment, NetworkAttachment> networkAttachmentMapper =
                 getMapper(org.ovirt.engine.api.model.NetworkAttachment.class, NetworkAttachment.class);
-        NetworkAttachment attachment;
+        NetworkAttachment attachment = null;
         if (model.isSetId()) {
-            Guid attachmentId = asGuid(model.getId());
-            attachment = networkAttachmentMapper.map(model, attachmentsById.get(attachmentId));
-        } else {
-            attachment = networkAttachmentMapper.map(model, null);
+            attachment = attachmentsById.get(asGuid(model.getId()));
+        } else if (model.isSetNetwork() && (model.getNetwork().isSetName() || model.getNetwork().isSetId())) {
+            for (Map.Entry<Guid, NetworkAttachment> backendNetworkAttachmentMapEntry : attachmentsById.entrySet()) {
+                NetworkAttachment backendNetworkAttachment = backendNetworkAttachmentMapEntry.getValue();
+                String backendNetworkName = backendNetworkAttachment.getNetworkName();
+                String backendNetworkId = backendNetworkAttachment.getNetworkId().toString();
+                if (backendNetworkName.equals(model.getNetwork().getName()) ||
+                        backendNetworkId.equals(model.getNetwork().getId())) {
+                    attachment = backendNetworkAttachment;
+                    break;
+                }
+            }
         }
 
-        return attachment;
+        return networkAttachmentMapper.map(model,  attachment);
     }
 
+
     public CreateOrUpdateBond mapBonds(BusinessEntityMap<Bond> bonds, HostNic model) {
         Mapper<HostNic, Bond> hostNicMapper = getMapper(HostNic.class, Bond.class);
         Bond bond;
