@@ -1,5 +1,11 @@
 package org.ovirt.engine.api.restapi.resource;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
@@ -18,7 +24,9 @@ import javax.ws.rs.core.Response;
 import javax.ws.rs.core.UriInfo;
 
 import org.apache.commons.codec.binary.Base64;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.mockito.junit.jupiter.MockitoSettings;
+import org.mockito.quality.Strictness;
 import org.ovirt.engine.api.model.Action;
 import org.ovirt.engine.api.model.Bios;
 import org.ovirt.engine.api.model.Boot;
@@ -80,6 +88,7 @@ import org.ovirt.engine.core.common.queries.QueryType;
 import org.ovirt.engine.core.common.utils.VmDeviceType;
 import org.ovirt.engine.core.compat.Guid;
 
+@MockitoSettings(strictness = Strictness.LENIENT)
 public class BackendVmResourceTest
         extends AbstractBackendSubResourceTest<Vm, org.ovirt.engine.core.common.businessentities.VM, BackendVmResource> {
 
@@ -102,29 +111,20 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testBadGuid() throws Exception {
-        try {
-            new BackendVmResource("foo", new BackendVmsResource());
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyNotFoundException(wae);
-        }
+    public void testBadGuid() {
+        verifyNotFoundException(assertThrows(
+                WebApplicationException.class, () -> new BackendVmResource("foo", new BackendVmsResource())));
     }
 
     @Test
-    public void testGetNotFound() throws Exception {
+    public void testGetNotFound() {
         setUriInfo(setUpBasicUriExpectations());
         setUpGetEntityExpectations(1, true);
-        try {
-            resource.get();
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyNotFoundException(wae);
-        }
+        verifyNotFoundException(assertThrows(WebApplicationException.class, resource::get));
     }
 
     @Test
-    public void testGet() throws Exception {
+    public void testGet() {
         setUriInfo(setUpBasicUriExpectations());
         setUpGetEntityExpectations(1);
         setUpGetPayloadExpectations(0, 1);
@@ -137,7 +137,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testGetNextConfiguration() throws Exception {
+    public void testGetNextConfiguration() {
         setUriInfo(addMatrixParameterExpectations(setUpBasicUriExpectations(), BackendVmResource.NEXT_RUN));
         setUpGetEntityNextRunExpectations();
         setUpGetPayloadExpectations(0, 1);
@@ -150,7 +150,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testGetIncludeStatistics() throws Exception {
+    public void testGetIncludeStatistics() {
         try {
             accepts.add("application/xml; detail=statistics");
             setUriInfo(setUpBasicUriExpectations());
@@ -168,16 +168,16 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testGetWithConsoleSet() throws Exception {
+    public void testGetWithConsoleSet() {
         testGetConsoleAware(true);
     }
 
     @Test
-    public void testGetWithConsoleNotSet() throws Exception {
+    public void testGetWithConsoleNotSet() {
         testGetConsoleAware(false);
     }
 
-    public void testGetConsoleAware(boolean allContent) throws Exception {
+    public void testGetConsoleAware(boolean allContent) {
         setUriInfo(setUpBasicUriExpectations());
         if (allContent) {
             List<String> populates = new ArrayList<>();
@@ -204,19 +204,14 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateNotFound() throws Exception {
+    public void testUpdateNotFound() {
         setUriInfo(setUpBasicUriExpectations());
         setUpGetEntityExpectations(1, true);
-        try {
-            resource.update(getModel(0));
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyNotFoundException(wae);
-        }
+        verifyNotFoundException(assertThrows(WebApplicationException.class, () -> resource.update(getModel(0))));
     }
 
     @Test
-    public void testUpdate() throws Exception {
+    public void testUpdate() {
         setUpGetEntityExpectations(3);
         setUpGetEntityForUpdateExpectations(3);
 
@@ -240,7 +235,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateRemovingPayloads() throws Exception {
+    public void testUpdateRemovingPayloads() {
         setUpGetEntityExpectations(3);
         setUpGetEntityForUpdateExpectations(3);
 
@@ -268,7 +263,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateUploadIcon() throws Exception {
+    public void testUpdateUploadIcon() {
         setUpGetEntityExpectations(3);
         setUpGetEntityForUpdateExpectations(3);
 
@@ -293,7 +288,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateUseExistingIcons() throws Exception {
+    public void testUpdateUseExistingIcons() {
         setUpGetEntityExpectations(3);
         setUpGetEntityForUpdateExpectations(3);
 
@@ -319,16 +314,12 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateSetAndUploadIconFailure() throws Exception {
+    public void testUpdateSetAndUploadIconFailure() {
         final Vm model = getModel(0);
         model.setSmallIcon(IconTestHelpler.createIcon(GUIDS[2]));
         model.setLargeIcon(IconTestHelpler.createIconWithData());
-        try {
-            verifyModel(resource.update(model), 0);
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyFault(wae, BAD_REQUEST);
-        }
+        verifyFault(
+                assertThrows(WebApplicationException.class, () -> verifyModel(resource.update(model), 0)), BAD_REQUEST);
     }
 
     protected void verifyModelClearingPayloads(Vm model, int index) {
@@ -344,7 +335,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateVmPolicySingleHostName() throws Exception {
+    public void testUpdateVmPolicySingleHostName() {
         setUpUdpateVm();
         setUpGetHostByNameExpectations(1);
         setUriInfo(setUpActionExpectations(ActionType.UpdateVm,
@@ -364,7 +355,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateVmPolicySingleHostId() throws Exception {
+    public void testUpdateVmPolicySingleHostId() {
         setUpUdpateVm();
         setUriInfo(setUpActionExpectations(ActionType.UpdateVm,
                 VmManagementParametersBase.class,
@@ -382,7 +373,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateVmPolicyHostsIds() throws Exception {
+    public void testUpdateVmPolicyHostsIds() {
         setUpUdpateVm();
         setUriInfo(setUpActionExpectations(ActionType.UpdateVm,
                 VmManagementParametersBase.class,
@@ -404,7 +395,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateVmPolicyHostsNames() throws Exception {
+    public void testUpdateVmPolicyHostsNames() {
         setUpUdpateVm();
         for (int i =0; i < NAMES.length; i++){
             setUpGetHostByNameExpectations(i);
@@ -428,7 +419,7 @@ public class BackendVmResourceTest
         verifyModel(resource.update(model), 0);
     }
 
-    private void setUpUdpateVm() throws Exception {
+    private void setUpUdpateVm() {
         setUpGetEntityExpectations(3);
         setUpGetEntityForUpdateExpectations(3);
 
@@ -445,7 +436,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateMovingCluster() throws Exception {
+    public void testUpdateMovingCluster() {
         setUpGetEntityExpectations(3);
         setUpGetEntityForUpdateExpectations(3);
 
@@ -481,16 +472,16 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUpdateCantDo() throws Exception {
+    public void testUpdateCantDo() {
         doTestBadUpdate(false, true, CANT_DO);
     }
 
     @Test
-    public void testUpdateFailed() throws Exception {
+    public void testUpdateFailed() {
         doTestBadUpdate(true, false, FAILURE);
     }
 
-    private void doTestBadUpdate(boolean valid, boolean success, String detail) throws Exception {
+    private void doTestBadUpdate(boolean valid, boolean success, String detail) {
         setUpGetEntityExpectations(2);
         setUpGetEntityForUpdateExpectations(2);
 
@@ -504,16 +495,11 @@ public class BackendVmResourceTest
                 valid,
                 success));
 
-        try {
-            resource.update(getModel(0));
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyFault(wae, detail);
-        }
+        verifyFault(assertThrows(WebApplicationException.class, () -> resource.update(getModel(0))), detail);
     }
 
     @Test
-    public void testConflictedUpdate() throws Exception {
+    public void testConflictedUpdate() {
         setUpGetEntityExpectations(2);
         setUpGetEntityForUpdateExpectations(2);
 
@@ -525,16 +511,11 @@ public class BackendVmResourceTest
 
         Vm model = getModel(1);
         model.setId(GUIDS[1].toString());
-        try {
-            resource.update(model);
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyImmutabilityConstraint(wae);
-        }
+        verifyImmutabilityConstraint(assertThrows(WebApplicationException.class, () -> resource.update(model)));
     }
 
     @Test
-    public void testStart() throws Exception {
+    public void testStart() {
         setUriInfo(setUpActionExpectations(ActionType.RunVm,
                 RunVmParams.class,
                 new String[] { "VmId" },
@@ -546,7 +527,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithVm() throws Exception {
+    public void testStartWithVm() {
         setUpWindowsGetEntityExpectations(1, false);
 
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
@@ -562,7 +543,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithPauseAndStateless() throws Exception {
+    public void testStartWithPauseAndStateless() {
         setUpWindowsGetEntityExpectations(1, false);
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
                                            RunVmOnceParams.class,
@@ -578,16 +559,16 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithSpice() throws Exception {
+    public void testStartWithSpice() {
         testStartWithModifiedGraphics(GraphicsType.SPICE);
     }
 
     @Test
-    public void testStartWithVnc() throws Exception {
+    public void testStartWithVnc() {
         testStartWithModifiedGraphics(GraphicsType.VNC);
     }
 
-    private void testStartWithModifiedGraphics(GraphicsType graphicsType) throws Exception {
+    private void testStartWithModifiedGraphics(GraphicsType graphicsType) {
         setUpWindowsGetEntityExpectations(1, false);
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
                                            RunVmOnceParams.class,
@@ -606,7 +587,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithBootDev() throws Exception {
+    public void testStartWithBootDev() {
         setUpWindowsGetEntityExpectations(1, false);
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
                                            RunVmOnceParams.class,
@@ -624,7 +605,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithBootMenu() throws Exception {
+    public void testStartWithBootMenu() {
         setUpWindowsGetEntityExpectations(1, false);
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
                                            RunVmOnceParams.class,
@@ -640,7 +621,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithCdRomAndFloppy() throws Exception {
+    public void testStartWithCdRomAndFloppy() {
         setUpWindowsGetEntityExpectations(1, false);
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
                                            RunVmOnceParams.class,
@@ -662,7 +643,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithHostId() throws Exception {
+    public void testStartWithHostId() {
         Host host = new Host();
         host.setId(GUIDS[1].toString());
 
@@ -670,7 +651,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStartWithHostName() throws Exception {
+    public void testStartWithHostName() {
         setUpGetHostByNameExpectations(1);
 
         Host host = new Host();
@@ -679,7 +660,7 @@ public class BackendVmResourceTest
         testStartWithHost(host, GUIDS[1]);
     }
 
-    protected void testStartWithHost(Host host, Guid hostId) throws Exception {
+    protected void testStartWithHost(Host host, Guid hostId) {
         setUpWindowsGetEntityExpectations(1, false);
         setUriInfo(setUpActionExpectations(ActionType.RunVmOnce,
                                            RunVmOnceParams.class,
@@ -697,7 +678,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testSuspend() throws Exception {
+    public void testSuspend() {
         setUriInfo(setUpActionExpectations(ActionType.HibernateVm,
                 VmOperationParameterBase.class,
                 new String[] { "VmId" },
@@ -707,21 +688,21 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testSuspendAsyncPending() throws Exception {
+    public void testSuspendAsyncPending() {
         doTestSuspendAsync(AsyncTaskStatusEnum.init, CreationStatus.PENDING);
     }
 
     @Test
-    public void testSuspendAsyncInProgress() throws Exception {
+    public void testSuspendAsyncInProgress() {
         doTestSuspendAsync(AsyncTaskStatusEnum.running, CreationStatus.IN_PROGRESS);
     }
 
     @Test
-    public void testSuspendAsyncFinished() throws Exception {
+    public void testSuspendAsyncFinished() {
         doTestSuspendAsync(AsyncTaskStatusEnum.finished, CreationStatus.COMPLETE);
     }
 
-    private void doTestSuspendAsync(AsyncTaskStatusEnum asyncStatus, CreationStatus actionStatus) throws Exception {
+    private void doTestSuspendAsync(AsyncTaskStatusEnum asyncStatus, CreationStatus actionStatus) {
         setUriInfo(setUpActionExpectations(ActionType.HibernateVm,
                                                 VmOperationParameterBase.class,
                                                 new String[] { "VmId" },
@@ -738,7 +719,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testShutdown() throws Exception {
+    public void testShutdown() {
         setUriInfo(setUpActionExpectations(ActionType.ShutdownVm,
                 ShutdownVmParameters.class,
                 new String[] { "VmId" },
@@ -748,7 +729,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testReboot() throws Exception {
+    public void testReboot() {
         setUriInfo(setUpActionExpectations(ActionType.RebootVm,
                                            VmOperationParameterBase.class,
                                            new String[] { "VmId" },
@@ -758,7 +739,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testReorderMacAddresses() throws Exception {
+    public void testReorderMacAddresses() {
 
         setUpGetEntityExpectations(QueryType.GetVmByVmId,
                 IdQueryParameters.class,
@@ -775,7 +756,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testStop() throws Exception {
+    public void testStop() {
         setUriInfo(setUpActionExpectations(ActionType.StopVm,
                                            StopVmParameters.class,
                                            new String[] { "VmId", "StopVmType" },
@@ -785,7 +766,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testCancelMigration() throws Exception {
+    public void testCancelMigration() {
         setUriInfo(setUpActionExpectations(ActionType.CancelMigrateVm,
                                            VmOperationParameterBase.class,
                                            new String[] { "VmId" },
@@ -795,7 +776,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testDetach() throws Exception {
+    public void testDetach() {
         setUriInfo(setUpActionExpectations(ActionType.RemoveVmFromPool,
                                            RemoveVmFromPoolParameters.class,
                                            new String[] { "VmId" },
@@ -805,7 +786,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testTicket() throws Exception {
+    public void testTicket() {
         setUpGetEntityExpectations(1);
         setUriInfo(setUpActionExpectations(ActionType.SetVmTicket,
                                            SetVmTicketParameters.class,
@@ -819,7 +800,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testLogon() throws Exception {
+    public void testLogon() {
         setUriInfo(setUpActionExpectations(ActionType.VmLogon,
                                            VmOperationParameterBase.class,
                                            new String[] { "VmId" },
@@ -830,7 +811,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testFreezeFilesystems() throws Exception {
+    public void testFreezeFilesystems() {
         setUriInfo(setUpActionExpectations(ActionType.FreezeVm,
                 VmOperationParameterBase.class,
                 new String[] { "VmId" },
@@ -841,7 +822,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testThawFilesystems() throws Exception {
+    public void testThawFilesystems() {
         setUriInfo(setUpActionExpectations(ActionType.ThawVm,
                 VmOperationParameterBase.class,
                 new String[] { "VmId" },
@@ -852,7 +833,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testMigrateWithHostId() throws Exception {
+    public void testMigrateWithHostId() {
         setUriInfo(setUpActionExpectations(ActionType.MigrateVmToServer,
                                            MigrateVmToServerParameters.class,
                                            new String[] { "VmId", "VdsId", "ForceMigrationForNonMigratableVm" },
@@ -865,7 +846,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testPreviewSnapshot() throws Exception {
+    public void testPreviewSnapshot() {
         setUriInfo(setUpActionExpectations(ActionType.TryBackToAllSnapshotsOfVm,
                                            TryBackToAllSnapshotsOfVmParameters.class,
                                            new String[] { "VmId", "DstSnapshotId" },
@@ -882,7 +863,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testUndoSnapshot() throws Exception {
+    public void testUndoSnapshot() {
         setUriInfo(setUpActionExpectations(ActionType.RestoreAllSnapshots,
                                            RestoreAllSnapshotsParameters.class,
                                            new String[] { "VmId", "SnapshotAction" },
@@ -895,7 +876,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testCommitSnapshot() throws Exception {
+    public void testCommitSnapshot() {
         setUriInfo(setUpActionExpectations(ActionType.RestoreAllSnapshots,
                                            RestoreAllSnapshotsParameters.class,
                                            new String[] { "VmId", "SnapshotAction" },
@@ -908,7 +889,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testCloneVm() throws Exception {
+    public void testCloneVm() {
         org.ovirt.engine.core.common.businessentities.VM mockedVm = mock(org.ovirt.engine.core.common.businessentities.VM.class);
         VmStatic vmStatic = mock(VmStatic.class);
         when(mockedVm.getStaticData()).thenReturn(vmStatic);
@@ -932,7 +913,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testMigrateWithHostName() throws Exception {
+    public void testMigrateWithHostName() {
         setUpGetHostByNameExpectations(1);
 
         setUriInfo(setUpActionExpectations(ActionType.MigrateVmToServer,
@@ -947,7 +928,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testMigrateNoHost() throws Exception {
+    public void testMigrateNoHost() {
         setUriInfo(setUpActionExpectations(ActionType.MigrateVm,
                 MigrateVmParameters.class,
                 new String[] { "VmId", "ForceMigrationForNonMigratableVm" },
@@ -957,7 +938,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testMigrateWithClusterId() throws Exception {
+    public void testMigrateWithClusterId() {
         setUriInfo(setUpActionExpectations(ActionType.MigrateVm,
                 MigrateVmParameters.class,
                 new String[] { "VmId", "ForceMigrationForNonMigratableVm", "TargetClusterId"},
@@ -972,17 +953,17 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testExport() throws Exception {
+    public void testExport() {
         testExportWithStorageDomainId(false, false);
     }
 
     @Test
-    public void testExportWithParams() throws Exception {
+    public void testExportWithParams() {
         testExportWithStorageDomainId(true, true);
     }
 
     @Test
-    public void testExportWithStorageDomainName() throws Exception {
+    public void testExportWithStorageDomainName() {
         setUpEntityQueryExpectations(QueryType.GetStorageDomainByName,
                 NameQueryParameters.class,
                 new String[] { "Name" },
@@ -995,7 +976,7 @@ public class BackendVmResourceTest
         doTestExport(storageDomain, false, false);
     }
 
-    protected void testExportWithStorageDomainId(boolean exclusive, boolean discardSnapshots) throws Exception {
+    protected void testExportWithStorageDomainId(boolean exclusive, boolean discardSnapshots) {
         StorageDomain storageDomain = new StorageDomain();
         storageDomain.setId(GUIDS[2].toString());
         doTestExport(storageDomain, exclusive, discardSnapshots);
@@ -1003,7 +984,7 @@ public class BackendVmResourceTest
 
     protected void doTestExport(StorageDomain storageDomain,
                                 boolean exclusive,
-                                boolean discardSnapshots) throws Exception {
+                                boolean discardSnapshots) {
         setUriInfo(setUpActionExpectations(ActionType.ExportVm,
                                            MoveOrCopyParameters.class,
                                            new String[] { "ContainerId", "StorageDomainId", "ForceOverride", "CopyCollapse" },
@@ -1033,7 +1014,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testMaintenance() throws Exception {
+    public void testMaintenance() {
         setUpGetEntityExpectations(1);
         setUriInfo(setUpActionExpectations(ActionType.SetHaMaintenance,
                                            SetHaMaintenanceParameters.class,
@@ -1046,7 +1027,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testRemove() throws Exception {
+    public void testRemove() {
         setUriInfo(setUpBasicUriExpectations());
         setUpGetEntityExpectations();
         setUpGetPayloadExpectations(0, 1);
@@ -1058,7 +1039,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testRemoveForced() throws Exception {
+    public void testRemoveForced() {
         setUpGetEntityExpectations();
         setUpGetPayloadExpectations(0, 1);
         setUpGetBallooningExpectations();
@@ -1078,7 +1059,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testRemoveDetachOnly() throws Exception {
+    public void testRemoveDetachOnly() {
         setUpGetEntityExpectations();
         setUpGetPayloadExpectations(0, 1);
         setUpGetBallooningExpectations();
@@ -1098,7 +1079,7 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testRemoveForcedIncomplete() throws Exception {
+    public void testRemoveForcedIncomplete() {
         setUpGetEntityExpectations();
         setUpGetPayloadExpectations(0, 1);
         setUpGetBallooningExpectations();
@@ -1118,23 +1099,17 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testRemoveNonExistant() throws Exception {
+    public void testRemoveNonExistant() {
         setUpGetEntityExpectations(QueryType.GetVmByVmId,
                 IdQueryParameters.class,
                 new String[] { "Id" },
                 new Object[] { GUIDS[0] },
                 null);
         setUriInfo(setUpBasicUriExpectations());
-        try {
-            resource.remove();
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            assertNotNull(wae.getResponse());
-            assertEquals(404, wae.getResponse().getStatus());
-        }
+        verifyNotFoundException(assertThrows(WebApplicationException.class, () -> resource.remove()));
     }
 
-    private void setUpGetEntityExpectations() throws Exception {
+    private void setUpGetEntityExpectations() {
         setUpGetEntityExpectations(QueryType.GetVmByVmId,
                 IdQueryParameters.class,
                 new String[] { "Id" },
@@ -1143,16 +1118,16 @@ public class BackendVmResourceTest
     }
 
     @Test
-    public void testRemoveCantDo() throws Exception {
+    public void testRemoveCantDo() {
         doTestBadRemove(false, true, CANT_DO);
     }
 
     @Test
-    public void testRemoveFailed() throws Exception {
+    public void testRemoveFailed() {
         doTestBadRemove(true, false, FAILURE);
     }
 
-    protected void doTestBadRemove(boolean valid, boolean success, String detail) throws Exception {
+    protected void doTestBadRemove(boolean valid, boolean success, String detail) {
         setUpGetEntityExpectations();
         setUpGetPayloadExpectations(0, 1);
         setUpGetBallooningExpectations();
@@ -1163,15 +1138,11 @@ public class BackendVmResourceTest
                 new Object[] { GUIDS[0], Boolean.FALSE },
                 valid,
                 success));
-        try {
-            resource.remove();
-            fail("expected WebApplicationException");
-        } catch (WebApplicationException wae) {
-            verifyFault(wae, detail);
-        }
+
+        verifyFault(assertThrows(WebApplicationException.class, resource::remove), detail);
     }
 
-    protected org.ovirt.engine.core.common.businessentities.VM setUpStatisticalExpectations() throws Exception {
+    protected org.ovirt.engine.core.common.businessentities.VM setUpStatisticalExpectations() {
         org.ovirt.engine.core.common.businessentities.VM entity = new org.ovirt.engine.core.common.businessentities.VM();
         setUpStatisticalEntityExpectations(entity, entity.getStatisticsData());
         setUpGetEntityExpectations(1, false, entity);
@@ -1186,27 +1157,29 @@ public class BackendVmResourceTest
         List<Statistic> statistics = query.getStatistics(entity);
         verifyStatistics(statistics,
                 new String[]{"memory.installed", "memory.used", "memory.free", "memory.buffered", "memory.cached",
-                        "cpu.current.guest", "cpu.current.hypervisor", "cpu.current.total", "migration.progress"},
+                        "cpu.current.guest", "cpu.current.hypervisor", "cpu.current.total", "migration.progress",
+                        "network.current.total", "cpu.usage.history", "memory.usage.history", "network.usage.history", "disks.usage"},
                 new BigDecimal[]{asDec(10 * Mb), asDec(2 * Mb), asDec(5 * Mb), asDec(2 * Mb), asDec(1 * Mb),
-                        asDec(30), asDec(40), asDec(70), asDec(50)});
+                        asDec(30), asDec(40), asDec(70), asDec(50), asDec(10), asDec(3), asDec(6), asDec(9),
+                null});
         Statistic adopted = query.adopt(new Statistic());
         assertTrue(adopted.isSetVm());
         assertEquals(GUIDS[0].toString(), adopted.getVm().getId());
     }
 
-    protected void setUpGetEntityExpectations(int times) throws Exception {
+    protected void setUpGetEntityExpectations(int times) {
         setUpGetEntityExpectations(times, false);
     }
 
-    protected void setUpGetEntityForUpdateExpectations(int times) throws Exception {
+    protected void setUpGetEntityForUpdateExpectations(int times) {
         setUpGetEntityExpectations(QueryType.GetVmByVmIdForUpdate, times, false, getEntity(0));
     }
 
-    protected void setUpGetEntityExpectations(int times, boolean notFound) throws Exception {
+    protected void setUpGetEntityExpectations(int times, boolean notFound) {
         setUpGetEntityExpectations(times, notFound, getEntity(0));
     }
 
-    protected void setUpWindowsGetEntityExpectations(int times, boolean notFound) throws Exception {
+    protected void setUpWindowsGetEntityExpectations(int times, boolean notFound) {
         setUpGetEntityExpectations(times,
                                    notFound,
                 new org.ovirt.engine.core.common.businessentities.VM() {{
@@ -1216,12 +1189,12 @@ public class BackendVmResourceTest
     }
 
     protected void setUpGetEntityExpectations(int times, boolean notFound,
-                                              org.ovirt.engine.core.common.businessentities.VM entity) throws Exception {
+                                              org.ovirt.engine.core.common.businessentities.VM entity) {
         setUpGetEntityExpectations(QueryType.GetVmByVmId, times, notFound, entity);
     }
 
     private void setUpGetEntityExpectations(QueryType queryType, int times, boolean notFound,
-                                            org.ovirt.engine.core.common.businessentities.VM entity) throws Exception {
+                                            org.ovirt.engine.core.common.businessentities.VM entity) {
         while (times-- > 0) {
             setUpGetEntityExpectations(queryType,
                                        IdQueryParameters.class,
@@ -1231,7 +1204,7 @@ public class BackendVmResourceTest
         }
     }
 
-    protected void setUpGetEntityNextRunExpectations() throws Exception {
+    protected void setUpGetEntityNextRunExpectations() {
         setUpGetEntityExpectations(QueryType.GetVmNextRunConfiguration,
                 IdQueryParameters.class,
                 new String[] { "Id" },
@@ -1256,7 +1229,7 @@ public class BackendVmResourceTest
         return setUpActionExpectations(task, clz, names, values, true, true, null, asyncTasks, asyncStatuses, null, null, uri, true);
     }
 
-    private void verifyActionResponse(Response r) throws Exception {
+    private void verifyActionResponse(Response r) {
         verifyActionResponse(r, "vms/" + GUIDS[0], false);
     }
 
@@ -1298,7 +1271,7 @@ public class BackendVmResourceTest
         return dom;
     }
 
-    protected void setUpGetPayloadExpectations(int index, int times) throws Exception {
+    protected void setUpGetPayloadExpectations(int index, int times) {
         for (int i = 0; i < times; i++) {
             setUpGetEntityExpectations(QueryType.GetVmPayload,
                                        IdQueryParameters.class,
@@ -1315,7 +1288,7 @@ public class BackendVmResourceTest
         return payload;
     }
 
-    protected void setUpGetNoPayloadExpectations(int index, int times) throws Exception {
+    protected void setUpGetNoPayloadExpectations(int index, int times) {
         for (int i = 0; i < times; i++) {
             setUpGetEntityExpectations(QueryType.GetVmPayload,
                                        IdQueryParameters.class,
@@ -1325,7 +1298,7 @@ public class BackendVmResourceTest
         }
     }
 
-    private void setUpGetBallooningExpectations() throws Exception {
+    private void setUpGetBallooningExpectations() {
         setUpGetEntityExpectations(QueryType.IsBalloonEnabled,
                 IdQueryParameters.class,
                 new String[] { "Id" },
@@ -1333,7 +1306,7 @@ public class BackendVmResourceTest
                 true);
     }
 
-    protected void setUpGetGraphicsExpectations(int times) throws Exception {
+    protected void setUpGetGraphicsExpectations(int times) {
         for (int i = 0; i < times; i++) {
             setUpGetEntityExpectations(QueryType.GetGraphicsDevices,
                     IdQueryParameters.class,
@@ -1343,7 +1316,7 @@ public class BackendVmResourceTest
         }
     }
 
-    protected void setUpGetNextRunGraphicsExpectations(int times) throws Exception {
+    protected void setUpGetNextRunGraphicsExpectations(int times) {
         for (int i = 0; i < times; i++) {
             setUpGetEntityExpectations(QueryType.GetNextRunGraphicsDevices,
                     IdQueryParameters.class,
@@ -1353,7 +1326,7 @@ public class BackendVmResourceTest
         }
     }
 
-    private void setUpGetCertuficateExpectations() throws Exception {
+    private void setUpGetCertuficateExpectations() {
         setUpGetEntityExpectations(QueryType.GetVdsCertificateSubjectByVmId,
                 IdQueryParameters.class,
                 new String[] { "Id" },
@@ -1361,7 +1334,7 @@ public class BackendVmResourceTest
                 CERTIFICATE);
     }
 
-    private void setUpGetVirtioScsiExpectations(int ... idxs) throws Exception {
+    private void setUpGetVirtioScsiExpectations(int ... idxs) {
         for (int i = 0; i < idxs.length; i++) {
             setUpGetEntityExpectations(QueryType.GetVirtioScsiControllers,
                     IdQueryParameters.class,
@@ -1371,7 +1344,7 @@ public class BackendVmResourceTest
         }
     }
 
-    private void setUpGetSoundcardExpectations(int ... idxs) throws Exception {
+    private void setUpGetSoundcardExpectations(int ... idxs) {
         for (int i = 0; i < idxs.length; i++) {
             setUpGetEntityExpectations(QueryType.GetSoundDevices,
                     IdQueryParameters.class,
@@ -1381,7 +1354,7 @@ public class BackendVmResourceTest
         }
     }
 
-    private void setUpGetVmOvfExpectations(int ... idxs) throws Exception {
+    private void setUpGetVmOvfExpectations(int ... idxs) {
         for (int i = 0; i < idxs.length; i++) {
             setUpGetEntityExpectations(QueryType.GetVmOvfByVmId,
                     GetVmOvfByVmIdParameters.class,
@@ -1391,7 +1364,7 @@ public class BackendVmResourceTest
         }
     }
 
-    protected void setUpGetHostByNameExpectations(int idx) throws Exception {
+    protected void setUpGetHostByNameExpectations(int idx) {
         VDS host = BackendHostsResourceTest.setUpEntityExpectations(spy(new VDS()), idx);
         setUpGetEntityExpectations(QueryType.GetVdsByName,
                 NameQueryParameters.class,
