@@ -315,4 +315,16 @@ public abstract class OvfOvirtReader extends OvfReader {
 
         super.readDiskImageItem(node, image);
     }
+
+    @Override
+    protected String adjustHardwareResourceType(String resourceType) {
+        switch(resourceType) {
+        case OvfHardware.OVIRT_Monitor:
+            return OvfHardware.Monitor;
+        case OvfHardware.OVIRT_Graphics:
+            return OvfHardware.Graphics;
+        default:
+            return super.adjustHardwareResourceType(resourceType);
+        }
+    }
 }
