@@ -268,11 +268,7 @@ public abstract class OvfWriter implements IOvfBuilder {
         }
 
         // TODO dedicated to multiple hosts - are we breaking any standard here?
-        if (vmBase.getDedicatedVmForVdsList().size() > 0) {
-            for (Guid hostId : vmBase.getDedicatedVmForVdsList()) {
-                _writer.writeElement(DEDICATED_VM_FOR_VDS, String.valueOf(hostId));
-            }
-        }
+        vmBase.getDedicatedVmForVdsList().forEach(d -> _writer.writeElement(DEDICATED_VM_FOR_VDS, String.valueOf(d)));
 
         if (vmBase.getSerialNumberPolicy() != null) {
             _writer.writeElement(SERIAL_NUMBER_POLICY, String.valueOf(vmBase.getSerialNumberPolicy().getValue()));
@@ -301,6 +297,7 @@ public abstract class OvfWriter implements IOvfBuilder {
         }
 
         writeCustomEmulatedMachine();
+        _writer.writeElement(BIOS_TYPE, String.valueOf(vmBase.getBiosType().getValue()));
         writeCustomCpuName();
 
         _writer.writeElement(PREDEFINED_PROPERTIES, vmBase.getPredefinedProperties());
@@ -534,7 +531,8 @@ public abstract class OvfWriter implements IOvfBuilder {
             _writer.writeElement(RASD_URI, "Template", image.getImageTemplateId().toString());
             _writer.writeElement(RASD_URI, "ApplicationList", image.getAppList());
             if (image.getStorageIds() != null && image.getStorageIds().size() > 0) {
-                _writer.writeElement(RASD_URI, "StorageId", image.getStorageIds().get(0).toString());
+                image.getStorageIds().forEach(guid ->
+                        _writer.writeElement(RASD_URI, "StorageId", guid.toString()));
             }
             if (image.getStoragePoolId() != null) {
                 _writer.writeElement(RASD_URI, "StoragePoolId", image.getStoragePoolId().toString());
