@@ -1,10 +1,10 @@
 package org.ovirt.engine.core.utils.ovf;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.util.Date;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class OvfParserTest {
 
