@@ -44,6 +44,7 @@ import org.ovirt.engine.core.common.businessentities.SupportedAdditionalClusterF
 import org.ovirt.engine.core.common.businessentities.VM;
 import org.ovirt.engine.core.common.businessentities.VdsNumaNode;
 import org.ovirt.engine.core.common.businessentities.VdsStatistics;
+import org.ovirt.engine.core.common.businessentities.VgpuPlacement;
 import org.ovirt.engine.core.common.businessentities.VmDevice;
 import org.ovirt.engine.core.common.businessentities.VmDeviceGeneralType;
 import org.ovirt.engine.core.common.businessentities.VmDeviceId;
@@ -89,6 +90,7 @@ import org.ovirt.engine.core.dao.HostDeviceDao;
 import org.ovirt.engine.core.dao.StorageDomainStaticDao;
 import org.ovirt.engine.core.dao.StorageServerConnectionDao;
 import org.ovirt.engine.core.dao.VdsNumaNodeDao;
+import org.ovirt.engine.core.dao.VdsStaticDao;
 import org.ovirt.engine.core.dao.VdsStatisticsDao;
 import org.ovirt.engine.core.dao.VmDeviceDao;
 import org.ovirt.engine.core.dao.VmNumaNodeDao;
@@ -140,6 +142,7 @@ public class VmInfoBuildUtils {
     private final StorageDomainStaticDao storageDomainStaticDao;
     private final StorageServerConnectionDao storageServerConnectionDao;
     private final VdsNumaNodeDao vdsNumaNodeDao;
+    private final VdsStaticDao vdsStaticDao;
     private final VdsStatisticsDao vdsStatisticsDao;
     private final HostDeviceDao hostDeviceDao;
     private final DiskVmElementDao diskVmElementDao;
@@ -171,6 +174,7 @@ public class VmInfoBuildUtils {
             StorageDomainStaticDao storageDomainStaticDao,
             StorageServerConnectionDao storageServerConnectionDao,
             VdsNumaNodeDao vdsNumaNodeDao,
+            VdsStaticDao vdsStaticDao,
             VdsStatisticsDao vdsStatisticsDao,
             HostDeviceDao hostDeviceDao,
             VmSerialNumberBuilder vmSerialNumberBuilder,
@@ -192,6 +196,7 @@ public class VmInfoBuildUtils {
         this.storageDomainStaticDao = Objects.requireNonNull(storageDomainStaticDao);
         this.storageServerConnectionDao = Objects.requireNonNull(storageServerConnectionDao);
         this.vdsNumaNodeDao = Objects.requireNonNull(vdsNumaNodeDao);
+        this.vdsStaticDao = Objects.requireNonNull(vdsStaticDao);
         this.vdsStatisticsDao = Objects.requireNonNull(vdsStatisticsDao);
         this.hostDeviceDao = Objects.requireNonNull(hostDeviceDao);
         this.vmSerialNumberBuilder = Objects.requireNonNull(vmSerialNumberBuilder);
@@ -539,8 +544,7 @@ public class VmInfoBuildUtils {
                     Integer controllerInt = Integer.valueOf(controllerStr);
 
                     boolean controllerOutOfRange = controllerInt >= vm.getNumOfIoThreads() + getDefaultVirtioScsiIndex(vm, dve.getDiskInterface());
-                    boolean ioThreadsEnabled = vm.getNumOfIoThreads() > 0 &&
-                            FeatureSupported.virtioScsiIoThread(vm.getCompatibilityVersion());
+                    boolean ioThreadsEnabled = vm.getNumOfIoThreads() > 0;
 
                     if ((ioThreadsEnabled && !controllerOutOfRange) ||
                             (controllerInt == getDefaultVirtioScsiIndex(vm, dve.getDiskInterface()))) {
@@ -602,12 +606,6 @@ public class VmInfoBuildUtils {
         String controllerStr = address.get(VdsProperties.Controller);
 
         int defaultIndex = getDefaultVirtioScsiIndex(vm, diskInterface);
-        boolean ioThreadsEnabled = FeatureSupported.virtioScsiIoThread(vm.getCompatibilityVersion());
-
-        if (!ioThreadsEnabled) {
-            // no io threads, only 1 controller allowed and it is the default one
-            return defaultIndex;
-        }
 
         if (StringUtils.isNotEmpty(controllerStr)) {
             int controllerInt = Integer.parseInt(controllerStr);
@@ -650,11 +648,14 @@ public class VmInfoBuildUtils {
     }
 
     public List<Disk> getSortedDisks(VM vm) {
-        // order first by drive numbers and then order by boot for the bootable
-        // drive to be first (important for IDE to be index 0) !
+        // Order the drives as following:
+        // - Boot devices of non-snapshot disks
+        // - Boot devices of snapshot disks (i.e., boot disks of other VMs plugged to this one
+        // - Then by the disk alias
         List<Disk> disks = new ArrayList<>(vm.getDiskMap().values());
-        Collections.sort(disks, new LexoNumericNameableComparator<>());
-        Collections.sort(disks, Collections.reverseOrder(new DiskByBootAndSnapshotComparator(vm.getId())));
+        disks.sort(Comparator.comparing((Disk d) -> !d.getDiskVmElementForVm(vm.getId()).isBoot())
+                .thenComparing(d -> d.getDiskVmElementForVm(vm.getId()).isBoot() && d.isDiskSnapshot())
+                .thenComparing(new LexoNumericNameableComparator<>()));
         return disks;
     }
 
@@ -859,7 +860,7 @@ public class VmInfoBuildUtils {
         return diskInterfaceToDevName(diskInterface) + (devIndex.isEmpty() ? 'a' : devIndex);
     }
 
-    private String diskInterfaceToDevName(String iface) {
+    public String diskInterfaceToDevName(String iface) {
         switch(iface) {
         case "virtio":
             return "vd";
@@ -1362,6 +1363,12 @@ public class VmInfoBuildUtils {
         return multiQueueUtils.isInterfaceQueuable(vmDevice, vmNic);
     }
 
+    public boolean isTabletEnabled(VM vm) {
+        return vm.getVmType() != VmType.HighPerformance // avoid adding Tablet device for HP VMs since no USB devices are set
+                && vm.getGraphicsInfos().size() == 1
+                && vm.getGraphicsInfos().containsKey(GraphicsType.VNC);
+    }
+
     public boolean shouldUseNativeIO(VM vm, DiskImage diskImage, VmDevice device) {
         StorageType storageType = diskImage.getStorageTypes().get(0);
         String diskType = getDiskType(vm, diskImage, device);
@@ -1371,4 +1378,8 @@ public class VmInfoBuildUtils {
         // marked as transient disk (file type) and uses cache when snapshotId is not null
         // so native io should not be used
     }
+
+    public VgpuPlacement vgpuPlacement(Guid hostId) {
+        return VgpuPlacement.forValue(vdsStaticDao.get(hostId).getVgpuPlacement());
+    }
 }
