@@ -13,7 +13,6 @@ import org.ovirt.engine.core.common.businessentities.Cluster;
 import org.ovirt.engine.core.common.businessentities.ExternalEntityBase;
 import org.ovirt.engine.core.common.businessentities.HostedEngineDeployConfiguration;
 import org.ovirt.engine.core.common.businessentities.Label;
-import org.ovirt.engine.core.common.businessentities.OpenstackNetworkProviderProperties;
 import org.ovirt.engine.core.common.businessentities.Provider;
 import org.ovirt.engine.core.common.businessentities.ProviderType;
 import org.ovirt.engine.core.common.businessentities.ServerCpu;
@@ -21,6 +20,7 @@ import org.ovirt.engine.core.common.businessentities.StoragePool;
 import org.ovirt.engine.core.common.businessentities.VDS;
 import org.ovirt.engine.core.common.businessentities.VDSStatus;
 import org.ovirt.engine.core.common.businessentities.VdsStatic;
+import org.ovirt.engine.core.common.businessentities.VgpuPlacement;
 import org.ovirt.engine.core.common.businessentities.pm.FenceAgent;
 import org.ovirt.engine.core.common.businessentities.pm.FenceProxySourceType;
 import org.ovirt.engine.core.common.mode.ApplicationMode;
@@ -48,6 +48,7 @@ import org.ovirt.engine.ui.uicommonweb.validation.HostnameValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.IValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.IntegerValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.LengthValidation;
+import org.ovirt.engine.ui.uicommonweb.validation.NoSpacesValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.NotEmptyValidation;
 import org.ovirt.engine.ui.uicommonweb.validation.SpecialAsciiI18NOrNoneValidation;
 import org.ovirt.engine.ui.uicompat.ConstantsManager;
@@ -163,6 +164,16 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         privateAuthSshPort = value;
     }
 
+    private EntityModel<Boolean> activateHostAfterInstall;
+
+    public EntityModel<Boolean> getActivateHostAfterInstall() {
+        return activateHostAfterInstall;
+    }
+
+    private void setActivateHostAfterInstall(EntityModel<Boolean> value) {
+        activateHostAfterInstall = value;
+    }
+
     private EntityModel<String> privateUserPassword;
 
     public EntityModel<String> getUserPassword() {
@@ -313,6 +324,54 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         this.consoleAddressEnabled = consoleAddressEnabled;
     }
 
+    private EntityModel<Boolean> vgpuConsolidatedPlacement;
+
+    public EntityModel<Boolean> getVgpuConsolidatedPlacement() {
+        return vgpuConsolidatedPlacement;
+    }
+
+    public void setVgpuConsolidatedPlacement(EntityModel<Boolean> vgpuConsolidatedPlacement) {
+        this.vgpuConsolidatedPlacement = vgpuConsolidatedPlacement;
+    }
+
+    private EntityModel<Boolean> vgpuSeparatedPlacement;
+
+    public EntityModel<Boolean> getVgpuSeparatedPlacement() {
+        return vgpuSeparatedPlacement;
+    }
+
+    public void setVgpuSeparatedPlacement(EntityModel<Boolean> vgpuSeparatedPlacement) {
+        this.vgpuSeparatedPlacement = vgpuSeparatedPlacement;
+    }
+
+    public VgpuPlacement getVgpuPlacement() {
+        if (vgpuSeparatedPlacement.getEntity()) {
+            return VgpuPlacement.SEPARATED;
+        } else {
+            return VgpuPlacement.CONSOLIDATED;
+        }
+    }
+
+    void setVgpuPlacement(VgpuPlacement vgpuPlacement) {
+        getVgpuSeparatedPlacement().setEntity(vgpuPlacement == VgpuPlacement.SEPARATED);
+        getVgpuConsolidatedPlacement().setEntity(vgpuPlacement == VgpuPlacement.CONSOLIDATED);
+    }
+
+    void setVgpuPlacementChangeability(Version version) {
+        boolean vgpuPlacementEnabled;
+        if (version == null) {
+            vgpuPlacementEnabled = false;
+        } else {
+            vgpuPlacementEnabled = AsyncDataProvider.getInstance().isVgpuPlacementSupported(version);
+        }
+        getVgpuConsolidatedPlacement().setIsChangeable(vgpuPlacementEnabled);
+        getVgpuSeparatedPlacement().setIsChangeable(vgpuPlacementEnabled);
+        if (! vgpuPlacementEnabled) {
+            getVgpuConsolidatedPlacement().setChangeProhibitionReason(constants.vgpuPlacementCompatibilityInfo());
+            getVgpuSeparatedPlacement().setChangeProhibitionReason(constants.vgpuPlacementCompatibilityInfo());
+        }
+    }
+
     private EntityModel<Boolean> pmKdumpDetection;
 
     public EntityModel<Boolean> getPmKdumpDetection() {
@@ -376,6 +435,16 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         this.kernelCmdlineParsable = kernelCmdlineParsable;
     }
 
+    private EntityModel<Boolean> kernelCmdlineBlacklistNouveau;
+
+    public EntityModel<Boolean> getKernelCmdlineBlacklistNouveau() {
+        return kernelCmdlineBlacklistNouveau;
+    }
+
+    public void setKernelCmdlineBlacklistNouveau(EntityModel<Boolean> kernelCmdlineBlacklistNouveau) {
+        this.kernelCmdlineBlacklistNouveau = kernelCmdlineBlacklistNouveau;
+    }
+
     private EntityModel<Boolean> kernelCmdlineIommu;
 
     public EntityModel<Boolean> getKernelCmdlineIommu() {
@@ -416,6 +485,16 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         this.kernelCmdlinePciRealloc = kernelCmdlinePciRealloc;
     }
 
+    private EntityModel<Boolean> kernelCmdlineFips;
+
+    public EntityModel<Boolean> getKernelCmdlineFips() {
+        return kernelCmdlineFips;
+    }
+
+    public void setKernelCmdlineFips(EntityModel<Boolean> kernelCmdlineFips) {
+        this.kernelCmdlineFips = kernelCmdlineFips;
+    }
+
     public String getPmProxyPreferences() {
         // Return null if power management is not enabled.
         if (!getIsPm().getEntity()) {
@@ -572,13 +651,13 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         this.externalHostProviderEnabled = externalHostProviderEnabled;
     }
 
-    private ListModel<Provider<OpenstackNetworkProviderProperties>> privateProviders;
+    private ListModel<Provider<Provider.AdditionalProperties>> privateProviders;
 
-    public ListModel<Provider<OpenstackNetworkProviderProperties>> getProviders() {
+    public ListModel<Provider<Provider.AdditionalProperties>> getProviders() {
         return privateProviders;
     }
 
-    protected void setProviders(ListModel<Provider<OpenstackNetworkProviderProperties>> value) {
+    protected void setProviders(ListModel<Provider<Provider.AdditionalProperties>> value) {
         privateProviders = value;
     }
 
@@ -657,16 +736,6 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
                 && hostsWithHeDeployed.get(0).equals(getHostId());
     }
 
-    private EntityModel<String> hostedEngineWarning;
-
-    public EntityModel<String> getHostedEngineWarning() {
-        return hostedEngineWarning;
-    }
-
-    public void setHostedEngineWarning(EntityModel<String> hostedEngineWarning) {
-        this.hostedEngineWarning = hostedEngineWarning;
-    }
-
     public HostModel() {
         setUpdateHostsCommand(new UICommand("", new ICommandTarget() { //$NON-NLS-1$
             @Override
@@ -697,6 +766,8 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         setPkSection(new EntityModel<Void>());
         setAuthSshPort(new EntityModel<Integer>());
         getAuthSshPort().setEntity(VdsStatic.DEFAULT_SSH_PORT);
+        setActivateHostAfterInstall(new EntityModel<Boolean>());
+        getActivateHostAfterInstall().setEntity(true);
         setUserName(new EntityModel<String>());
         getUserName().setEntity(RootUserName);
         // TODO: remove setIsChangeable when configured ssh username is enabled
@@ -724,7 +795,7 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         getExternalHostName().setIsAvailable(false);
         setExternalHostProviderEnabled(new EntityModel<>(false));
         getExternalHostProviderEnabled().setIsAvailable(false);
-        setProviders(new ListModel<Provider<OpenstackNetworkProviderProperties>>());
+        setProviders(new ListModel<>());
         getProviders().setIsAvailable(false);
         setProviderSearchFilter(new EntityModel<String>());
         getProviderSearchFilter().setIsAvailable(false);
@@ -767,19 +838,22 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         setNetworkProviderModel(new HostNetworkProviderModel());
         setIsDiscoveredHosts(new EntityModel<Boolean>());
         setKernelCmdline(new EntityModel<String>());
+        setKernelCmdlineBlacklistNouveau(new EntityModel<>(false));
         setKernelCmdlineIommu(new EntityModel<>(false));
         setKernelCmdlineKvmNested(new EntityModel<>(false));
         setKernelCmdlineUnsafeInterrupts(new EntityModel<>(false));
         setKernelCmdlinePciRealloc(new EntityModel<>(false));
+        setKernelCmdlineFips(new EntityModel<>(false));
         kernelCmdlineListener = new EnableableEventListener<>(null);
         setCurrentKernelCmdLine(new EntityModel<>(""));
         setHostedEngineHostModel(new HostedEngineHostModel());
         setLabelList(new ListModel<Label>());
         updateLabelList();
 
-        setHostedEngineWarning(new EntityModel<String>(constants.hostedEngineDeploymentCompatibilityWarning()));
-
         setPasswordSectionViewable(true);
+
+        setVgpuConsolidatedPlacement(new EntityModel<>(false));
+        setVgpuSeparatedPlacement(new EntityModel<>(false));
     }
 
     private void updatePmModels() {
@@ -812,8 +886,7 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
             if (fingerprint != null && fingerprint.length() > 0) {
                 getFetchSshFingerprint().setEntity(fingerprint);
                 getFetchResult().setEntity(ConstantsManager.getInstance().getConstants().successLoadingFingerprint());
-            }
-            else {
+            } else {
                 getFetchResult().setEntity(ConstantsManager.getInstance().getConstants().errorLoadingFingerprint());
             }
         });
@@ -825,8 +898,7 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         if (!getHost().getIsValid()) {
             getFetchResult().setEntity(ConstantsManager.getInstance().getConstants().fingerprintAddressError()
                     + getHost().getInvalidityReasons().get(0));
-        }
-        else {
+        } else {
             getFetchResult().setEntity(ConstantsManager.getInstance().getConstants().loadingFingerprint());
             AsyncDataProvider.getInstance().getHostFingerprint(
                     aQuery,
@@ -918,10 +990,12 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         } else if (sender == getConsoleAddressEnabled()) {
             consoleAddressChanged();
         } else if (ev.matchesDefinition(HasEntity.entityChangedEventDefinition)
-                && (sender == getKernelCmdlineIommu()
+                && (sender == getKernelCmdlineBlacklistNouveau()
+                || sender == getKernelCmdlineIommu()
                 || sender == getKernelCmdlineKvmNested()
                 || sender == getKernelCmdlineUnsafeInterrupts()
-                || sender == getKernelCmdlinePciRealloc())) {
+                || sender == getKernelCmdlinePciRealloc()
+                || sender == getKernelCmdlineFips())) {
             if (isKernelCmdlineParsable()) {
                 updateKernelCmdlineAccordingToCheckboxes();
             }
@@ -1019,8 +1093,9 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
             cpuVendorChanged();
         }
 
-        getHostedEngineWarning().setIsAvailable(cluster.getCompatibilityVersion().less(Version.v4_0));
         getNetworkProviderModel().setDefaultProviderId(cluster.getDefaultNetworkProviderId());
+
+        setVgpuPlacementChangeability(cluster.getCompatibilityVersion());
     }
 
     protected abstract void cpuVendorChanged();
@@ -1046,8 +1121,7 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
             });
             getExternalComputeResource().setIsValid(getExternalComputeResource().getSelectedItem() != null);
             getExternalHostGroups().setIsValid(getExternalHostGroups().getSelectedItem() != null);
-        }
-        else {
+        } else {
             getExternalComputeResource().setIsValid(true);
             getExternalHostGroups().setIsValid(true);
         }
@@ -1066,6 +1140,9 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         }
         setValidTab(TabName.CONSOLE_TAB, getConsoleAddress().getIsValid());
 
+        getKernelCmdline().validateEntity(new IValidation[] { new NoSpacesValidation() });
+        setValidTab(TabName.KERNEL_TAB, getKernelCmdline().getIsValid());
+
         getDataCenter().validateSelectedItem(new IValidation[] { new NotEmptyValidation() });
         getCluster().validateSelectedItem(new IValidation[] { new NotEmptyValidation() });
 
@@ -1091,7 +1168,8 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
 
         ValidationCompleteEvent.fire(getEventBus(), this);
         return isValidTab(TabName.GENERAL_TAB) && isValidTab(TabName.POWER_MANAGEMENT_TAB)
-                && getConsoleAddress().getIsValid() && getNetworkProviderModel().getIsValid();
+                && getConsoleAddress().getIsValid() && getNetworkProviderModel().getIsValid()
+                && isValidTab(TabName.KERNEL_TAB);
     }
 
     public void updateModelFromVds(VDS vds,
@@ -1110,13 +1188,15 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
         getUserName().setEntity(vds.getSshUsername());
         getAuthSshPort().setEntity(vds.getSshPort());
         if (StringHelper.isNotNullOrEmpty(vds.getKernelArgs())) {
-            getCurrentKernelCmdLine().setEntity(constants.currentKernelCmdLine() + vds.getKernelArgs());
+            getCurrentKernelCmdLine().setEntity(constants.currentKernelCmdLine() + " " + vds.getKernelArgs()); //$NON-NLS-1$
         }
         setPort(vds);
         boolean consoleAddressEnabled = vds.getConsoleAddress() != null;
         getConsoleAddressEnabled().setEntity(consoleAddressEnabled);
         getConsoleAddress().setEntity(vds.getConsoleAddress());
         getConsoleAddress().setIsChangeable(consoleAddressEnabled);
+        setVgpuPlacement(VgpuPlacement.forValue(vds.getVgpuPlacement()));
+        setVgpuPlacementChangeability(getCluster().getSelectedItem().getCompatibilityVersion());
 
         if (!showInstallationProperties()) {
             getPkSection().setIsChangeable(false);
@@ -1153,10 +1233,12 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
 
         getKernelCmdline().setEntity(vds.getCurrentKernelCmdline());
         setKernelCmdlineParsable(vds.isKernelCmdlineParsable());
+        getKernelCmdlineBlacklistNouveau().setEntity(vds.isKernelCmdlineBlacklistNouveau());
         getKernelCmdlineIommu().setEntity(vds.isKernelCmdlineIommu());
         getKernelCmdlineKvmNested().setEntity(vds.isKernelCmdlineKvmNested());
         getKernelCmdlineUnsafeInterrupts().setEntity(vds.isKernelCmdlineUnsafeInterrupts());
         getKernelCmdlinePciRealloc().setEntity(vds.isKernelCmdlinePciRealloc());
+        getKernelCmdlineFips().setEntity(vds.isKernelCmdlineFips());
     }
 
     public List<FenceAgentModel> getFenceAgentModelList(VDS vds) {
@@ -1210,10 +1292,10 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
 
     private void updateExternalHostModels(final Guid selected) {
         AsyncDataProvider.getInstance().getAllProvidersByType(new AsyncQuery<>(result -> {
-            List<Provider<OpenstackNetworkProviderProperties>> providers = (List) result;
-            ListModel<Provider<OpenstackNetworkProviderProperties>> providersListModel = getProviders();
+            List<Provider<Provider.AdditionalProperties>> providers = (List) result;
+            ListModel<Provider<Provider.AdditionalProperties>> providersListModel = getProviders();
             if (selected != null) {
-                for (Provider<OpenstackNetworkProviderProperties> provider: providers) {
+                for (Provider<Provider.AdditionalProperties> provider: providers) {
                     if (provider.getId().equals(selected)) {
                         providersListModel.setItems(providers, provider);
                         getExternalHostProviderEnabled().setEntity(true);
@@ -1295,17 +1377,21 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
     }
 
     private void setKernelCmdlineCheckboxesChangeability(boolean changeable, String reason) {
+        getKernelCmdlineBlacklistNouveau().setIsChangeable(changeable, reason);
         getKernelCmdlineIommu().setIsChangeable(changeable, reason);
         getKernelCmdlineKvmNested().setIsChangeable(changeable, reason);
         getKernelCmdlineUnsafeInterrupts().setIsChangeable(changeable, reason);
         getKernelCmdlinePciRealloc().setIsChangeable(changeable, reason);
+        getKernelCmdlineFips().setIsChangeable(changeable, reason);
     }
 
     private void setKernelCmdlineCheckboxesValue(boolean checked) {
+        getKernelCmdlineBlacklistNouveau().setEntity(checked);
         getKernelCmdlineIommu().setEntity(checked);
         getKernelCmdlineKvmNested().setEntity(checked);
         getKernelCmdlineUnsafeInterrupts().setEntity(checked);
         getKernelCmdlinePciRealloc().setEntity(checked);
+        getKernelCmdlineFips().setEntity(checked);
     }
 
     /**
@@ -1326,27 +1412,33 @@ public abstract class HostModel extends Model implements HasValidatedTabs {
     }
 
     private void addKernelCmdlineCheckboxesListeners() {
+        getKernelCmdlineBlacklistNouveau().getEntityChangedEvent().addListener(this);
         getKernelCmdlineIommu().getEntityChangedEvent().addListener(this);
         getKernelCmdlineKvmNested().getEntityChangedEvent().addListener(this);
         getKernelCmdlineUnsafeInterrupts().getEntityChangedEvent().addListener(this);
         getKernelCmdlinePciRealloc().getEntityChangedEvent().addListener(this);
+        getKernelCmdlineFips().getEntityChangedEvent().addListener(this);
     }
 
     private void updateKernelCmdlineAccordingToCheckboxes() {
         final CpuVendor cpuVendor = getCurrentCpuVendor();
         if (cpuVendor == null
+                || getKernelCmdlineBlacklistNouveau().getEntity() == null
                 || getKernelCmdlineIommu().getEntity() == null
                 || getKernelCmdlineKvmNested().getEntity() == null
                 || getKernelCmdlineUnsafeInterrupts().getEntity() == null
-                || getKernelCmdlinePciRealloc().getEntity() == null) {
+                || getKernelCmdlinePciRealloc().getEntity() == null
+                || getKernelCmdlineFips().getEntity() == null) {
             return;
         }
         final String kernelCmdline = KernelCmdlineUtil.create(
                 cpuVendor,
+                getKernelCmdlineBlacklistNouveau().getEntity(),
                 getKernelCmdlineIommu().getEntity(),
                 getKernelCmdlineKvmNested().getEntity(),
                 getKernelCmdlineUnsafeInterrupts().getEntity(),
-                getKernelCmdlinePciRealloc().getEntity());
+                getKernelCmdlinePciRealloc().getEntity(),
+                getKernelCmdlineFips().getEntity());
         kernelCmdlineListener.whilePaused(() -> getKernelCmdline().setEntity(kernelCmdline));
     }
 
