@@ -125,14 +125,14 @@ public interface UIMessages extends Messages {
 
     String templateVersionNameAndNumber(String versionName, int versionNumber);
 
-    String diskAlignment(String alignment, String lastScanDate);
-
     String errConnectingVmUsingSpiceMsg(Object errCode);
 
     String errConnectingVmUsingRdpMsg(Object errCode);
 
     String areYouSureYouWantToDeleteSanpshot(String from, Object description);
 
+    String areYouSureYouWantToCommitSnapshot(String from, Object description);
+
     String editBondInterfaceTitle(String name);
 
     String editHostNicVfsConfigTitle(String name);
@@ -421,6 +421,8 @@ public interface UIMessages extends Messages {
 
     String highPerformancePopupRecommendationMsgForKsm(String clusterName);
 
+    String biosTypeSupportedForX86Only();
+
     String glusterPeerNotMatchingHostFingerprint(String hostAddress, String glusterPeerAddress);
 }
 
