@@ -19,6 +19,10 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String loginButtonLabel();
 
+    String logMaxMemoryUsedThresholdLabel();
+
+    String logMaxMemoryUsedThresholdLabelHelpMessage();
+
     String configureLinkLabel();
 
     String logoutLinkLabel();
@@ -330,6 +334,10 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String storagePopupVfsTypeLabel();
 
+    String StoragePopupDriverOptionsLabel();
+
+    String StoragePopupDriverSensitiveOptionsLabel();
+
     String storagePopupMountOptionsLabel();
 
     String storagePopupAdditionalMountOptionsLabel();
@@ -566,6 +574,14 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String consoleButtonLabel();
 
+    String vgpuPlacementLabel();
+
+    String vgpuPlacementInfoIcon();
+
+    String vgpuConsolidatedPlacementLabel();
+
+    String vgpuSeparatedPlacementLabel();
+
     String networkProviderButtonLabel();
 
     String externalNetworkProviderLabel();
@@ -828,18 +844,6 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String vmExportPopupCollapseSnapshotsLabel();
 
-    String vmMigratePopupSelectHostAutomaticallyLabel();
-
-    String vmMigratePopupSelectDestinationHostLabel();
-
-    String vmMigratePopupHostsListLabel();
-
-    String vmMigrateHostDisabledVMsInServerClusters();
-
-    String vmMigrateSomeVmsAlreadyRunningOnHost();
-
-    String vmMigrateNoAvailableHost();
-
     String importVm_destCluster();
 
     String importVm_destClusterQuota();
@@ -1490,8 +1494,6 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String consoleVm();
 
-    String migrateVm();
-
     String cancelMigrationVm();
 
     String cancelConvertVm();
@@ -1500,9 +1502,9 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String exportVm();
 
-    String exportVmToExportDomain();
+    String exportToExportDomain();
 
-    String exportVmToOva();
+    String exportToOva();
 
     String createSnapshotVM();
 
@@ -3377,6 +3379,8 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String hostedEngineStorageTooltip();
 
+    String backupStorageTooltip();
+
     String isUnmanaged();
 
     String haActiveTooltip();
@@ -3461,6 +3465,8 @@ public interface ApplicationConstants extends CommonApplicationConstants {
 
     String resetBrickBrick();
 
+    String showVfInfo();
+
     String ovsVersionGeneral();
 
     String enabledVirtualFunctions();
@@ -3482,4 +3488,14 @@ public interface ApplicationConstants extends CommonApplicationConstants {
     String ipHostImportCluster();
 
     String glusterPeerAddress();
+
+    String vncEncryptionEnabled();
+
+    String vncEncryptionEnabledHelpMessage();
+
+    String vncEncryptionLabel();
+
+    String vdsmName();
+
+    String portSecurityEnabledLabel();
 }
