@@ -1,11 +1,18 @@
 package org.ovirt.engine.ui.webadmin.section.main.view.tab.datacenter;
 
+import org.ovirt.engine.core.common.businessentities.StoragePool;
 import org.ovirt.engine.ui.common.idhandler.ElementIdHandler;
+import org.ovirt.engine.ui.common.presenter.OvirtBreadCrumbsPresenterWidget;
 import org.ovirt.engine.ui.common.widget.tab.AbstractTabPanel;
+import org.ovirt.engine.ui.common.widget.tab.DetailTabLayout;
+import org.ovirt.engine.ui.uicommonweb.models.datacenters.DataCenterListModel;
+import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.DataCenterActionPanelPresenterWidget;
 import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.datacenter.DataCenterSubTabPanelPresenter;
 import org.ovirt.engine.ui.webadmin.section.main.view.AbstractSubTabPanelView;
 import org.ovirt.engine.ui.webadmin.widget.tab.SimpleTabPanel;
+
 import com.google.gwt.core.client.GWT;
+import com.google.inject.Inject;
 
 public class DataCenterSubTabPanelView extends AbstractSubTabPanelView implements DataCenterSubTabPanelPresenter.ViewDef {
 
@@ -13,10 +20,14 @@ public class DataCenterSubTabPanelView extends AbstractSubTabPanelView implement
         ViewIdHandler idHandler = GWT.create(ViewIdHandler.class);
     }
 
-    private final SimpleTabPanel tabPanel = new SimpleTabPanel();
+    private final SimpleTabPanel tabPanel;
 
-    public DataCenterSubTabPanelView() {
+    @Inject
+    public DataCenterSubTabPanelView(OvirtBreadCrumbsPresenterWidget<StoragePool, DataCenterListModel> breadCrumbs,
+            DataCenterActionPanelPresenterWidget actionPanel, DetailTabLayout detailTabLayout) {
+        tabPanel = new SimpleTabPanel(breadCrumbs, actionPanel, detailTabLayout);
         initWidget(getTabPanel());
+        actionPanel.removeButton(actionPanel.getNewButtonDefinition());
     }
 
     @Override
