@@ -1,11 +1,18 @@
 package org.ovirt.engine.ui.webadmin.section.main.view.tab.storage;
 
+import org.ovirt.engine.core.common.businessentities.StorageDomain;
 import org.ovirt.engine.ui.common.idhandler.ElementIdHandler;
+import org.ovirt.engine.ui.common.presenter.OvirtBreadCrumbsPresenterWidget;
 import org.ovirt.engine.ui.common.widget.tab.AbstractTabPanel;
+import org.ovirt.engine.ui.common.widget.tab.DetailTabLayout;
+import org.ovirt.engine.ui.uicommonweb.models.storage.StorageListModel;
+import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.StorageActionPanelPresenterWidget;
 import org.ovirt.engine.ui.webadmin.section.main.presenter.tab.storage.StorageSubTabPanelPresenter;
 import org.ovirt.engine.ui.webadmin.section.main.view.AbstractSubTabPanelView;
 import org.ovirt.engine.ui.webadmin.widget.tab.SimpleTabPanel;
+
 import com.google.gwt.core.client.GWT;
+import com.google.inject.Inject;
 
 public class StorageSubTabPanelView extends AbstractSubTabPanelView implements StorageSubTabPanelPresenter.ViewDef {
 
@@ -13,10 +20,15 @@ public class StorageSubTabPanelView extends AbstractSubTabPanelView implements S
         ViewIdHandler idHandler = GWT.create(ViewIdHandler.class);
     }
 
-    private final SimpleTabPanel tabPanel = new SimpleTabPanel();
+    private final SimpleTabPanel tabPanel;
 
-    public StorageSubTabPanelView() {
+    @Inject
+    public StorageSubTabPanelView(OvirtBreadCrumbsPresenterWidget<StorageDomain, StorageListModel> breadCrumbs,
+            StorageActionPanelPresenterWidget actionPanel, DetailTabLayout detailTabLayout) {
+        tabPanel = new SimpleTabPanel(breadCrumbs, actionPanel, detailTabLayout);
         initWidget(getTabPanel());
+        actionPanel.removeButton(actionPanel.getNewButtonDefinition());
+        actionPanel.removeButton(actionPanel.getImportButtonDefinition());
     }
 
     @Override
